@@ -12,10 +12,12 @@
 #include <cstdlib>
 #include <iomanip>
 #include <iostream>
+#include <random>
 #include <string>
 
 #include <set>
 #include <tlx/container/btree_multiset.hpp>
+#include <tlx/container/splay_tree.hpp>
 #include <unordered_set>
 
 #include <map>
@@ -23,6 +25,7 @@
 #include <unordered_map>
 
 #include <tlx/die.hpp>
+#include <tlx/timestamp.hpp>
 
 // *** Settings
 
@@ -32,22 +35,17 @@ const size_t min_items = 125;
 //! maximum number of items to insert
 const size_t max_items = 1024000 * 64;
 
-const int randseed = 34234235;
-
-//! Time is measured using chrono::steady_clock
-static double timestamp() {
-    return std::chrono::duration_cast<std::chrono::duration<double> >(
-        std::chrono::steady_clock::now().time_since_epoch()).count();
-}
+//! random seed
+const int seed = 34234235;
 
 //! Traits used for the speed tests, BTREE_DEBUG is not defined.
-template <int InnerSlots_, int LeafSlots_>
+template <int InnerSlots, int LeafSlots>
 struct btree_traits_speed : tlx::btree_default_traits<size_t, size_t> {
     static const bool self_verify = false;
     static const bool debug = false;
 
-    static const int leaf_slots = InnerSlots_;
-    static const int inner_slots = LeafSlots_;
+    static const int leaf_slots = InnerSlots;
+    static const int inner_slots = LeafSlots;
 
     static const size_t binsearch_threshold = 256 * 1024 * 1024; // never
 };
@@ -66,9 +64,9 @@ public:
     void run(size_t items) {
         SetType set;
 
-        srand(randseed);
+        std::default_random_engine rng(seed);
         for (size_t i = 0; i < items; i++)
-            set.insert(rand());
+            set.insert(rng());
 
         die_unless(set.size() == items);
     }
@@ -86,19 +84,19 @@ public:
     void run(size_t items) {
         SetType set;
 
-        srand(randseed);
+        std::default_random_engine rng(seed);
         for (size_t i = 0; i < items; i++)
-            set.insert(rand());
+            set.insert(rng());
 
         die_unless(set.size() == items);
 
-        srand(randseed);
+        rng.seed(seed);
         for (size_t i = 0; i < items; i++)
-            set.find(rand());
+            set.find(rng());
 
-        srand(randseed);
+        rng.seed(seed);
         for (size_t i = 0; i < items; i++)
-            set.erase(set.find(rand()));
+            set.erase(set.find(rng()));
 
         die_unless(set.empty());
     }
@@ -114,17 +112,17 @@ public:
     static const char * op() { return "set_find"; }
 
     Test_Set_Find(size_t items) {
-        srand(randseed);
+        std::default_random_engine rng(seed);
         for (size_t i = 0; i < items; i++)
-            set.insert(rand());
+            set.insert(rng());
 
         die_unless(set.size() == items);
     }
 
     void run(size_t items) {
-        srand(randseed);
+        std::default_random_engine rng(seed);
         for (size_t i = 0; i < items; i++)
-            set.find(rand());
+            set.find(rng());
     }
 };
 
@@ -134,6 +132,9 @@ struct TestFactory_Set {
     //! Test the multiset red-black tree from STL
     typedef TestClass<std::multiset<size_t> > StdSet;
 
+    //! Test the multiset red-black tree from STL
+    typedef TestClass<tlx::splay_multiset<size_t> > SplaySet;
+
     //! Test the unordered_set from STL TR1
     typedef TestClass<std::unordered_multiset<size_t> > UnorderedSet;
 
@@ -167,9 +168,9 @@ public:
     void run(size_t items) {
         MapType map;
 
-        srand(randseed);
+        std::default_random_engine rng(seed);
         for (size_t i = 0; i < items; i++) {
-            size_t r = rand();
+            size_t r = rng();
             map.insert(std::make_pair(r, r));
         }
 
@@ -189,21 +190,21 @@ public:
     void run(size_t items) {
         MapType map;
 
-        srand(randseed);
+        std::default_random_engine rng(seed);
         for (size_t i = 0; i < items; i++) {
-            size_t r = rand();
+            size_t r = rng();
             map.insert(std::make_pair(r, r));
         }
 
         die_unless(map.size() == items);
 
-        srand(randseed);
+        rng.seed(seed);
         for (size_t i = 0; i < items; i++)
-            map.find(rand());
+            map.find(rng());
 
-        srand(randseed);
+        rng.seed(seed);
         for (size_t i = 0; i < items; i++)
-            map.erase(map.find(rand()));
+            map.erase(map.find(rng()));
 
         die_unless(map.empty());
     }
@@ -219,9 +220,9 @@ public:
     static const char * op() { return "map_find"; }
 
     Test_Map_Find(size_t items) {
-        srand(randseed);
+        std::default_random_engine rng(seed);
         for (size_t i = 0; i < items; i++) {
-            size_t r = rand();
+            size_t r = rng();
             map.insert(std::make_pair(r, r));
         }
 
@@ -229,9 +230,9 @@ public:
     }
 
     void run(size_t items) {
-        srand(randseed);
+        std::default_random_engine rng(seed);
         for (size_t i = 0; i < items; i++)
-            map.find(rand());
+            map.find(rng());
     }
 };
 
@@ -280,7 +281,7 @@ void testrunner_loop(size_t items, const std::string& container_name) {
             // initialize test structures
             TestClass test(items);
 
-            ts1 = timestamp();
+            ts1 = tlx::timestamp();
 
             for (size_t r = 0; r <= repeat_until; r += items)
             {
@@ -289,7 +290,7 @@ void testrunner_loop(size_t items, const std::string& container_name) {
                 ++repeat;
             }
 
-            ts2 = timestamp();
+            ts2 = tlx::timestamp();
         }
 
         std::cout << "Insert " << items << " repeat " << (repeat_until / items)
@@ -308,6 +309,7 @@ void testrunner_loop(size_t items, const std::string& container_name) {
               << " time_total=" << (ts2 - ts1)
               << " time="
               << std::fixed << std::setprecision(10) << ((ts2 - ts1) / repeat)
+              << " items_per_sec=" << items / (ts2 - ts1)
               << std::endl;
 }
 
@@ -337,6 +339,7 @@ void TestFactory_Set<TestClass>::call_testrunner(size_t items) {
 
     testrunner_loop<StdSet>(items, "std::multiset");
     testrunner_loop<UnorderedSet>(items, "std::unordered_multiset");
+    testrunner_loop<SplaySet>(items, "tlx::splay_multiset");
 
 #if 0
     btree_range<BtreeSet, min_nodeslots, max_nodeslots>()(
