@@ -1,4 +1,3 @@
-// networkit-format
 
 #ifndef NETWORKIT_IO_COVER_READER_HPP_
 #define NETWORKIT_IO_COVER_READER_HPP_
@@ -20,7 +19,7 @@ public:
      * @param[in]  G     The graph for which the cover shall be read
      * @return The cover instance
      */
-    virtual Cover read(std::string path, Graph &G);
+    virtual Cover read(const std::string &path, Graph &G);
 };
 
 } /* namespace NetworKit */
