@@ -1,4 +1,3 @@
-// no-networkit-format
 /*
  * ApproxBetweennessGTest.cpp
  *
@@ -10,19 +9,19 @@
 
 #include <networkit/centrality/ApproxBetweenness.hpp>
 #include <networkit/centrality/Betweenness.hpp>
-#include <networkit/generators/ErdosRenyiGenerator.hpp>
-#include <networkit/generators/DorogovtsevMendesGenerator.hpp>
 #include <networkit/distance/Diameter.hpp>
+#include <networkit/generators/DorogovtsevMendesGenerator.hpp>
+#include <networkit/generators/ErdosRenyiGenerator.hpp>
 
 namespace NetworKit {
 
 class ApproxBetweennessGTest : public testing::Test {};
 
 TEST_F(ApproxBetweennessGTest, benchApproxDiameterErdos) {
-    ErdosRenyiGenerator gen(1000,0.002);
+    ErdosRenyiGenerator gen(1000, 0.002);
     Graph G1 = gen.generate();
     ApproxBetweenness approx(G1, 0.05, 0.1);
     approx.run();
 }
 
-}
+} // namespace NetworKit
