@@ -1,4 +1,3 @@
-// no-networkit-format
 /*
  * CentralityGTest.cpp
  *
@@ -8,6 +7,7 @@
 
 #include <iomanip>
 #include <iostream>
+#include <random>
 
 #include <gtest/gtest.h>
 
@@ -16,8 +16,8 @@
 #include <networkit/centrality/ApproxBetweenness.hpp>
 #include <networkit/centrality/ApproxCloseness.hpp>
 #include <networkit/centrality/ApproxElectricalCloseness.hpp>
-#include <networkit/centrality/ApproxSpanningEdge.hpp>
 #include <networkit/centrality/ApproxGroupBetweenness.hpp>
+#include <networkit/centrality/ApproxSpanningEdge.hpp>
 #include <networkit/centrality/Betweenness.hpp>
 #include <networkit/centrality/Closeness.hpp>
 #include <networkit/centrality/CoreDecomposition.hpp>
@@ -31,8 +31,8 @@
 #include <networkit/centrality/GedWalk.hpp>
 #include <networkit/centrality/GroupCloseness.hpp>
 #include <networkit/centrality/GroupClosenessGrowShrink.hpp>
-#include <networkit/centrality/GroupClosenessLocalSwaps.hpp>
 #include <networkit/centrality/GroupClosenessLocalSearch.hpp>
+#include <networkit/centrality/GroupClosenessLocalSwaps.hpp>
 #include <networkit/centrality/GroupDegree.hpp>
 #include <networkit/centrality/GroupHarmonicCloseness.hpp>
 #include <networkit/centrality/HarmonicCloseness.hpp>
@@ -45,16 +45,14 @@
 #include <networkit/centrality/PageRank.hpp>
 #include <networkit/centrality/PermanenceCentrality.hpp>
 #include <networkit/centrality/SpanningEdgeCentrality.hpp>
-#include <networkit/centrality/TopCloseness.hpp>
-#include <networkit/centrality/TopHarmonicCloseness.hpp>
 #include <networkit/components/ConnectedComponents.hpp>
 #include <networkit/distance/Dijkstra.hpp>
 #include <networkit/generators/DorogovtsevMendesGenerator.hpp>
 #include <networkit/generators/ErdosRenyiGenerator.hpp>
 #include <networkit/generators/HyperbolicGenerator.hpp>
-#include <networkit/graph/GraphTools.hpp>
 #include <networkit/graph/BFS.hpp>
 #include <networkit/graph/Dijkstra.hpp>
+#include <networkit/graph/GraphTools.hpp>
 #include <networkit/io/EdgeListReader.hpp>
 #include <networkit/io/METISGraphReader.hpp>
 #include <networkit/io/SNAPGraphReader.hpp>
@@ -70,13 +68,16 @@ protected:
 };
 
 INSTANTIATE_TEST_SUITE_P(InstantiationName, CentralityGTest,
-        testing::Values(std::make_pair(false, false), std::make_pair(true, false),
-                        std::make_pair(false, true),
-                        std::make_pair(true, true)));
+                         testing::Values(std::make_pair(false, false), std::make_pair(true, false),
+                                         std::make_pair(false, true), std::make_pair(true, true)));
 
-bool CentralityGTest::isWeighted() const noexcept { return GetParam().first; }
+bool CentralityGTest::isWeighted() const noexcept {
+    return GetParam().first;
+}
 
-bool CentralityGTest::isDirected() const noexcept { return GetParam().second; }
+bool CentralityGTest::isDirected() const noexcept {
+    return GetParam().second;
+}
 
 TEST_F(CentralityGTest, testBetweennessCentrality) {
     /* Graph:
@@ -102,17 +103,13 @@ TEST_F(CentralityGTest, testBetweennessCentrality) {
     std::vector<double> result = {0., 0., 15., 3., 3., 1.};
 
     const double tol = 1e-3;
-    G.forNodes([&](node u) {
-        EXPECT_NEAR(result[u], bc[u], tol);
-    });
+    G.forNodes([&](node u) { EXPECT_NEAR(result[u], bc[u], tol); });
 
     Betweenness centralityNorm(G, true);
     centralityNorm.run();
     bc = centralityNorm.scores();
     const double pairs = (n - 1) * (n - 2);
-    G.forNodes([&](node u) {
-        EXPECT_NEAR(result[u] / pairs, bc[u], tol);
-    });
+    G.forNodes([&](node u) { EXPECT_NEAR(result[u] / pairs, bc[u], tol); });
 }
 
 TEST_F(CentralityGTest, testBetweenness2Centrality) {
@@ -175,6 +172,16 @@ TEST_F(CentralityGTest, runApproxBetweennessSmallGraph) {
     DEBUG("scores: ", bc);
 }
 
+TEST_F(CentralityGTest, runApproxBetweenness) {
+    DorogovtsevMendesGenerator generator(100);
+    Graph G1 = generator.generate();
+    Graph G(G1, true, false);
+    ApproxBetweenness bc(G, 0.1, 0.1);
+    bc.run();
+    ApproxBetweenness bc1(G1, 0.1, 0.1);
+    bc1.run();
+}
+
 TEST_F(CentralityGTest, testBetweennessCentralityWeighted) {
     /* Graph:
      0    3   6
@@ -242,8 +249,7 @@ TEST_F(CentralityGTest, testKatzTopk) {
     auto exactRanking = exactAlgo.ranking();
     auto topRanking = topAlgo.ranking();
     for (count i = 0; i < std::min(G.numberOfNodes(), static_cast<count>(100)); i++)
-        EXPECT_NEAR(exactAlgo.score(topRanking[i].first),
-                    exactRanking[i].second, 1e-6);
+        EXPECT_NEAR(exactAlgo.score(topRanking[i].first), exactRanking[i].second, 1e-6);
 }
 
 TEST_F(CentralityGTest, testKatzDynamicAddition) {
@@ -266,9 +272,7 @@ TEST_F(CentralityGTest, testKatzDynamicAddition) {
     const edgeweight tol = 1e-9;
     for (count i = 0; i <= std::min(kc.levelReached, kc2.levelReached); i++) {
         INFO("i = ", i);
-        G.forNodes([&](node u) {
-            EXPECT_EQ(kc.nPaths[i][u], kc2.nPaths[i][u]);
-        });
+        G.forNodes([&](node u) { EXPECT_EQ(kc.nPaths[i][u], kc2.nPaths[i][u]); });
     }
     G.forNodes([&](node u) {
         EXPECT_NEAR(kc.score(u), kc2.score(u), tol);
@@ -298,8 +302,7 @@ TEST_F(CentralityGTest, testKatzDynamicDeletion) {
         INFO("i = ", i);
         G.forNodes([&](node u) {
             if (kc.nPaths[i][u] != kc2.nPaths[i][u]) {
-                INFO("i = ", i, ", node ", u,
-                     ", dyn kc paths: ", kc.nPaths[i][u],
+                INFO("i = ", i, ", node ", u, ", dyn kc paths: ", kc.nPaths[i][u],
                      ", stat paths: ", kc2.nPaths[i][u]);
             }
             EXPECT_EQ(kc.nPaths[i][u], kc2.nPaths[i][u]);
@@ -351,8 +354,7 @@ TEST_F(CentralityGTest, testKatzDynamicBuilding) {
     auto topRanking = topAlgo.ranking();
     auto dynRanking = dynAlgo.ranking();
     for (count i = 0; i < std::min(G.numberOfNodes(), count{100}); i++)
-        EXPECT_FALSE(
-            dynAlgo.areDistinguished(topRanking[i].first, dynRanking[i].first))
+        EXPECT_FALSE(dynAlgo.areDistinguished(topRanking[i].first, dynRanking[i].first))
             << "Nodes " << topRanking[i].first << " and " << dynRanking[i].first
             << " should not be distinguished!";
 }
@@ -408,8 +410,7 @@ TEST_F(CentralityGTest, testKatzDirectedAddition) {
     kc2.run();
 
     for (count i = 0; i <= std::min(kc.levelReached, kc2.levelReached); i++) {
-        G.forNodes(
-            [&](node u) { EXPECT_EQ(kc.nPaths[i][u], kc2.nPaths[i][u]); });
+        G.forNodes([&](node u) { EXPECT_EQ(kc.nPaths[i][u], kc2.nPaths[i][u]); });
     }
     const edgeweight tol = 1e-9;
     G.forNodes([&](node u) {
@@ -509,8 +510,8 @@ TEST_P(CentralityGTest, testPageRank) {
         EXPECT_LE(pr.numberOfIterations(), maxIterations);
     };
 
-    doTest(PageRank::Norm::L1Norm);
-    doTest(PageRank::Norm::L2Norm);
+    doTest(PageRank::Norm::L1_NORM);
+    doTest(PageRank::Norm::L2_NORM);
 }
 
 TEST_P(CentralityGTest, testNormalizedPageRank) {
@@ -518,18 +519,18 @@ TEST_P(CentralityGTest, testNormalizedPageRank) {
      0 <---> 1
      \-> 2 <-/
      3       4
-    
-     Node 0,1 have directed edges to each other. Both have also an 
-     edge to node 2. Node 3 and 4 are isolated from the rest (sinks). 
-     This example is taken from "Comparing Apples and Oranges: 
+
+     Node 0,1 have directed edges to each other. Both have also an
+     edge to node 2. Node 3 and 4 are isolated from the rest (sinks).
+     This example is taken from "Comparing Apples and Oranges:
      Normalized PageRank for Evolving Graphs" by Berberich et al.
-    */    
+    */
     count n = 5;
     Graph G(n, isWeighted(), isDirected());
-    G.addEdge(0,1);
-    G.addEdge(1,0);
-    G.addEdge(0,2);
-    G.addEdge(1,2);
+    G.addEdge(0, 1);
+    G.addEdge(1, 0);
+    G.addEdge(0, 2);
+    G.addEdge(1, 2);
 
     auto doTest = [&G](PageRank::Norm norm) {
         PageRank pr(G, 0.85, 1e-8, true, PageRank::SinkHandling::DISTRIBUTE_SINKS);
@@ -540,7 +541,7 @@ TEST_P(CentralityGTest, testNormalizedPageRank) {
         const double tol = 2e-4;
 
         // Values should be the same as in the original paper
-        if(G.isDirected()) {
+        if (G.isDirected()) {
             EXPECT_NEAR(pr_scores[0], 1.7391, tol);
             EXPECT_NEAR(pr_scores[1], 1.7391, tol);
             EXPECT_NEAR(pr_scores[2], 2.4781, tol);
@@ -553,11 +554,10 @@ TEST_P(CentralityGTest, testNormalizedPageRank) {
             EXPECT_NEAR(pr_scores[3], 1.0, tol);
             EXPECT_NEAR(pr_scores[4], 1.0, tol);
         }
-
     };
 
-    doTest(PageRank::Norm::L1Norm);
-    doTest(PageRank::Norm::L2Norm);
+    doTest(PageRank::Norm::L1_NORM);
+    doTest(PageRank::Norm::L2_NORM);
 }
 
 TEST_F(CentralityGTest, testEigenvectorCentrality) {
@@ -842,7 +842,7 @@ TEST_P(CentralityGTest, testClosenessCentrality) {
 
     if (isWeighted()) {
         Aux::Random::setSeed(42, false);
-        G.forEdges([&](node u, node v) { G.setWeight(u, v, Aux::Random::probability()); });
+        GraphTools::randomizeWeights(G);
     }
 
     auto computeCloseness = [&](node u, ClosenessVariant variant, bool normalized) {
@@ -854,7 +854,7 @@ TEST_P(CentralityGTest, testClosenessCentrality) {
         double reached = 0.;
 
         G.forNodes([&](node v) {
-            if (variant == ClosenessVariant::standard) {
+            if (variant == ClosenessVariant::STANDARD) {
                 sumDist += dists[v];
             } else if (dists[v] != std::numeric_limits<double>::max()) {
                 ++reached;
@@ -864,26 +864,26 @@ TEST_P(CentralityGTest, testClosenessCentrality) {
 
         double score = sumDist;
         if (score) {
-            score = (variant == ClosenessVariant::standard) ?
-                1.0 / score : (reached - 1.0) / sumDist / (G.numberOfNodes() - 1.0);
+            score = (variant == ClosenessVariant::STANDARD)
+                        ? 1.0 / score
+                        : (reached - 1.0) / sumDist / (G.numberOfNodes() - 1.0);
         }
 
         if (normalized) {
-            score *= (variant == ClosenessVariant::standard ? G.numberOfNodes() : reached) - 1.0;
+            score *= (variant == ClosenessVariant::STANDARD ? G.numberOfNodes() : reached) - 1.0;
         }
 
         return score;
     };
 
-    for (auto variant : {ClosenessVariant::standard, ClosenessVariant::generalized}) {
+    for (auto variant : {ClosenessVariant::STANDARD, ClosenessVariant::GENERALIZED}) {
         for (auto normalized : {true, false}) {
             Closeness centrality(G, normalized, variant);
             centrality.run();
             const auto bc = centrality.scores();
 
-            G.forNodes([&](node u) {
-                EXPECT_DOUBLE_EQ(bc[u], computeCloseness(u, variant, normalized));
-            });
+            G.forNodes(
+                [&](node u) { EXPECT_DOUBLE_EQ(bc[u], computeCloseness(u, variant, normalized)); });
         }
     }
 }
@@ -1022,8 +1022,7 @@ TEST_F(CentralityGTest, testCoreDecomposition) {
 
 TEST_F(CentralityGTest, benchCoreDecompositionLocal) {
     METISGraphReader reader;
-    std::vector<std::string> filenames = {"caidaRouterLevel", "wing",
-                                          "astro-ph", "PGPgiantcompo"};
+    std::vector<std::string> filenames = {"caidaRouterLevel", "wing", "astro-ph", "PGPgiantcompo"};
 
     for (auto f : filenames) {
         std::string filename("input/" + f + ".graph");
@@ -1041,11 +1040,10 @@ TEST_F(CentralityGTest, benchCoreDecompositionLocal) {
         timer.start();
         coreDec2.run();
         timer.stop();
-        INFO("Time for bucket queue based k-core decomposition of ", filename,
-             ": ", timer.elapsedTag());
+        INFO("Time for bucket queue based k-core decomposition of ", filename, ": ",
+             timer.elapsedTag());
 
-        G.forNodes(
-            [&](node u) { EXPECT_EQ(coreDec.score(u), coreDec2.score(u)); });
+        G.forNodes([&](node u) { EXPECT_EQ(coreDec.score(u), coreDec2.score(u)); });
     }
 }
 
@@ -1150,9 +1148,8 @@ TEST_F(CentralityGTest, testLocalClusteringCoefficientUndirected) {
     LocalClusteringCoefficient lcc(G);
     lcc.run();
     std::vector<double> lccScores = lcc.scores();
-    std::vector<double> reference = {0.0, 0.0, 0.0, 0.0,
-                                     0.0, 0.0, 0.5, 0.0,
-                                     0.8, 0.8, 0.8, 0.6666666666666666,
+    std::vector<double> reference = {0.0, 0.0, 0.0, 0.0, 0.0, 0.0,
+                                     0.5, 0.0, 0.8, 0.8, 0.8, 0.6666666666666666,
                                      0.0, 0.8, 0.5, 0.0};
 
     EXPECT_EQ(reference, lccScores);
@@ -1184,9 +1181,8 @@ TEST_F(CentralityGTest, testLocalClusteringCoefficientUndirected2) {
     LocalClusteringCoefficient lcc(G);
     lcc.run();
     std::vector<double> lccScores = lcc.scores();
-    std::vector<double> reference = {0.6666666666666666, 0.6666666666666666,
-                                     0.6666666666666666, 0.6666666666666666,
-                                     0.3333333333333333, 0.3333333333333333};
+    std::vector<double> reference = {0.6666666666666666, 0.6666666666666666, 0.6666666666666666,
+                                     0.6666666666666666, 0.3333333333333333, 0.3333333333333333};
 
     EXPECT_EQ(reference, lccScores);
 }
@@ -1204,10 +1200,8 @@ TEST_F(CentralityGTest, testLocalSquareClusteringCoefficientUndirected) {
     LocalSquareClusteringCoefficient lscc(G);
     lscc.run();
     std::vector<double> lccScores = lscc.scores();
-    std::vector<double> reference = {
-        0.3333333333333333, 1.0, 0.3333333333333333, 0.2,
-        0.3333333333333333, 1.0, 0.3333333333333333
-    };
+    std::vector<double> reference = {0.3333333333333333, 1.0, 0.3333333333333333, 0.2,
+                                     0.3333333333333333, 1.0, 0.3333333333333333};
 
     EXPECT_EQ(reference, lccScores);
 }
@@ -1274,66 +1268,6 @@ TEST_F(CentralityGTest, testSimplePermanence) {
     EXPECT_NEAR(0.167, perm.getPermanence(v), 0.0005);
 }
 
-TEST_P(CentralityGTest, testTopCloseness) {
-    constexpr count size = 400;
-    constexpr count k = 10;
-    Aux::Random::setSeed(42, false);
-    const auto G1 = DorogovtsevMendesGenerator(size).generate();
-    Graph G(G1, false, isDirected());
-
-    Closeness cc(G1, true, ClosenessVariant::generalized);
-    cc.run();
-    auto exactScores = cc.scores();
-    auto ranking = cc.ranking();
-    for (auto firstHeu : {true, false}) {
-        for (auto secHeu : {true, false}) {
-            TopCloseness topcc(G, k, firstHeu, secHeu);
-            topcc.run();
-            auto scores = topcc.topkScoresList();
-            EXPECT_EQ(topcc.topkNodesList().size(), k);
-            for (count i = 0; i < k; i++) {
-                EXPECT_DOUBLE_EQ(ranking[i].second, scores[i]);
-            }
-        }
-    }
-}
-
-TEST_P(CentralityGTest, testTopHarmonicCloseness) {
-    const count size = 400;
-    const double tol = 1e-6;
-
-    for (int seed : {1, 2, 3}) {
-        Aux::Random::setSeed(seed, false);
-        auto G = ErdosRenyiGenerator(size, 0.01, isDirected()).generate();
-        if (isWeighted()) {
-            G = GraphTools::toWeighted(G);
-            G.forEdges([&G](node u, node v) { G.setWeight(u, v, Aux::Random::probability()); });
-        }
-        HarmonicCloseness cc(G, false);
-        cc.run();
-        const auto ranking = cc.ranking();
-        for (bool useNBbound : {true, false}) {
-            for (count k : {5, 10, 20}) {
-                if (isWeighted() && useNBbound)
-                    continue;
-                TopHarmonicCloseness topcc(G, k, useNBbound);
-                topcc.run();
-
-                auto topkScores = topcc.topkScoresList();
-                EXPECT_EQ(topcc.topkNodesList().size(), k);
-                EXPECT_EQ(topkScores.size(), k);
-
-                topkScores = topcc.topkScoresList(true);
-
-                for (count i = 0; i < topkScores.size(); ++i)
-                    EXPECT_NEAR(ranking[i].second, topkScores[i], tol);
-                for (count i = k; i < topkScores.size(); ++i)
-                    EXPECT_NEAR(topkScores[i], topkScores[k - 1], tol);
-            }
-        }
-    }
-}
-
 TEST_F(CentralityGTest, testLaplacianCentrality) {
     // The graph structure and reference values for the scores are taken from
     // Qi et al., Laplacian centrality: A new centrality measure for weighted
@@ -1452,20 +1386,18 @@ TEST_P(CentralityGTest, testGroupDegree) {
     } while (std::next_permutation(reference.begin(), reference.end()));
 
     EXPECT_TRUE(scoreNoGroup > 0.5 * maxScore);
-    EXPECT_TRUE(scorePlusGroup >
-                (1.0 - 1.0 / std::exp(1.0)) * static_cast<double>(maxScore + k));
+    EXPECT_TRUE(scorePlusGroup > (1.0 - 1.0 / std::exp(1.0)) * static_cast<double>(maxScore + k));
     EXPECT_EQ(scoreNoGroup, gd.scoreOfGroup(gd.groupMaxDegree()));
-    EXPECT_EQ(scorePlusGroup,
-              gdIncludeGroup.scoreOfGroup(gdIncludeGroup.groupMaxDegree()));
+    EXPECT_EQ(scorePlusGroup, gdIncludeGroup.scoreOfGroup(gdIncludeGroup.groupMaxDegree()));
 }
 
 TEST_F(CentralityGTest, testGroupBetweennessScore) {
-/** 0           5
- *  | \       / |
- *  1 - 3 - 4 - 6
- *  | /       \ |
- *  2           7
- */
+    /** 0           5
+     *  | \       / |
+     *  1 - 3 - 4 - 6
+     *  | /       \ |
+     *  2           7
+     */
     Graph G(8, false, false);
     G.addEdge(0, 1);
     G.addEdge(1, 2);
@@ -1823,7 +1755,7 @@ TEST_F(CentralityGTest, testApproxSpanningEdge) {
     auto exactScores = se.scores();
 
     G.forEdges([&](node /*u*/, node /*v*/, edgeweight /*w*/, edgeid eid) {
-        EXPECT_NEAR(apxScores[eid], exactScores[eid], 2*eps);
+        EXPECT_NEAR(apxScores[eid], exactScores[eid], 2 * eps);
     });
 }
 
@@ -1833,8 +1765,8 @@ TEST_P(CentralityGTest, testGedWalk) {
     constexpr double epsilon = 0.01;
     auto g = ErdosRenyiGenerator(20, 0.1, isDirected()).generate();
 
-    for (const auto bs : {GedWalk::BoundStrategy::geometric, GedWalk::BoundStrategy::spectral}) {
-        for (const auto gs : {GedWalk::GreedyStrategy::lazy, GedWalk::GreedyStrategy::stochastic}) {
+    for (const auto bs : {GedWalk::BoundStrategy::GEOMETRIC, GedWalk::BoundStrategy::SPECTRAL}) {
+        for (const auto gs : {GedWalk::GreedyStrategy::LAZY, GedWalk::GreedyStrategy::STOCHASTIC}) {
             GedWalk gedWalk(g, k, epsilon, -1.0, bs, gs);
             gedWalk.run();
 
@@ -1894,7 +1826,7 @@ TEST_F(CentralityGTest, testApproxElectricalCloseness) {
 TEST_P(CentralityGTest, testGroupClosenessGrowShrink) {
     if (isDirected()) { // directed graphs are not supported
         Graph G(10, isWeighted(), true);
-        std::array<node, 1> group;
+        std::array<node, 1> group = {{0}};
         EXPECT_THROW(GroupClosenessGrowShrink(G, group.begin(), group.end()), std::runtime_error);
         return;
     }
@@ -1911,10 +1843,8 @@ TEST_P(CentralityGTest, testGroupClosenessGrowShrink) {
     G = ConnectedComponents::extractLargestConnectedComponent(G);
 
     if (isWeighted()) {
-        G = GraphTools::toWeighted(G);
-        G.forEdges([&G](const node u, const node v) {
-            G.setWeight(u, v, Aux::Random::probability());
-        });
+        Aux::Random::setSeed(42, false);
+        GraphTools::randomizeWeights(G);
     }
 
     auto farnessOfGroup = [&](const Graph &G, const std::unordered_set<node> &group) -> edgeweight {
@@ -1955,14 +1885,12 @@ TEST_P(CentralityGTest, testGroupClosenessGrowShrink) {
             EXPECT_GE(sumDist, sumDistGroupMaxCC);
         } else {
             EXPECT_EQ(sumDist, sumDistGroupMaxCC);
-            std::for_each(groupMaxCC.begin(), groupMaxCC.end(), [&group](const node u) {
-                EXPECT_NE(group.find(u), group.end());
-            });
+            std::for_each(groupMaxCC.begin(), groupMaxCC.end(),
+                          [&group](const node u) { EXPECT_NE(group.find(u), group.end()); });
         }
     }
 }
 
-
 TEST_P(CentralityGTest, testDegreeCentrality) {
     Graph g(8, false, isDirected());
 
@@ -1982,12 +1910,14 @@ TEST_P(CentralityGTest, testDegreeCentrality) {
     DegreeCentrality dc(g, false, true, false);
     dc.run();
 
-    if (isDirected()){
-        std::array<int ,8> expectedResults{{2, 1, 3, 1, 1, 3, 0, 1}};
-        for(long unsigned int i = 0; i < expectedResults.size(); i++) EXPECT_EQ(expectedResults[i], dc.score(i));
+    if (isDirected()) {
+        std::array<int, 8> expectedResults{{2, 1, 3, 1, 1, 3, 0, 1}};
+        for (long unsigned int i = 0; i < expectedResults.size(); i++)
+            EXPECT_EQ(expectedResults[i], dc.score(i));
     } else {
-        std::array<int ,8> expectedResults{{2, 1, 5, 2, 2, 6, 1, 2}};
-        for(long unsigned int i = 0; i < expectedResults.size(); i++) EXPECT_EQ(expectedResults[i], dc.score(i));
+        std::array<int, 8> expectedResults{{2, 1, 5, 2, 2, 6, 1, 2}};
+        for (long unsigned int i = 0; i < expectedResults.size(); i++)
+            EXPECT_EQ(expectedResults[i], dc.score(i));
     }
 }
 
@@ -2010,12 +1940,14 @@ TEST_P(CentralityGTest, testInDegreeCentrality) {
     DegreeCentrality dc(g, false, false, false);
     dc.run();
 
-    if (isDirected()){
-        std::array<int ,8> expectedResults{{0, 0, 3, 1, 1, 4, 1, 2}};
-        for(long unsigned int i = 0; i < expectedResults.size(); i++) EXPECT_EQ(expectedResults[i], dc.score(i));
+    if (isDirected()) {
+        std::array<int, 8> expectedResults{{0, 0, 3, 1, 1, 4, 1, 2}};
+        for (long unsigned int i = 0; i < expectedResults.size(); i++)
+            EXPECT_EQ(expectedResults[i], dc.score(i));
     } else {
-        std::array<int ,8> expectedResults{{2, 1, 5, 2, 2, 6, 1, 2}};
-        for(long unsigned int i = 0; i < expectedResults.size(); i++) EXPECT_EQ(expectedResults[i], dc.score(i));
+        std::array<int, 8> expectedResults{{2, 1, 5, 2, 2, 6, 1, 2}};
+        for (long unsigned int i = 0; i < expectedResults.size(); i++)
+            EXPECT_EQ(expectedResults[i], dc.score(i));
     }
 }
 
@@ -2038,19 +1970,21 @@ TEST_P(CentralityGTest, testDegreeCentralityIgnoreSelfLoops) {
     DegreeCentrality dc(g, false, true, true);
     dc.run();
 
-    if (isDirected()){
-        std::array<int ,8> expectedResults{{2, 1, 2, 1, 1, 2, 0, 0}};
-        for(long unsigned int i = 0; i < expectedResults.size(); i++) EXPECT_EQ(expectedResults[i], dc.score(i));
+    if (isDirected()) {
+        std::array<int, 8> expectedResults{{2, 1, 2, 1, 1, 2, 0, 0}};
+        for (long unsigned int i = 0; i < expectedResults.size(); i++)
+            EXPECT_EQ(expectedResults[i], dc.score(i));
     } else {
-        std::array<int ,8> expectedResults{{2, 1, 4, 2, 2, 5, 1, 1}};
-        for(long unsigned int i = 0; i < expectedResults.size(); i++) EXPECT_EQ(expectedResults[i], dc.score(i));
+        std::array<int, 8> expectedResults{{2, 1, 4, 2, 2, 5, 1, 1}};
+        for (long unsigned int i = 0; i < expectedResults.size(); i++)
+            EXPECT_EQ(expectedResults[i], dc.score(i));
     }
 }
 
 TEST_P(CentralityGTest, testGroupClosenessLocalSwaps) {
     if (isDirected()) { // directed graphs are not supported
         Graph G(10, isWeighted(), true);
-        std::array<node, 1> group;
+        std::array<node, 1> group = {{0}};
         EXPECT_THROW(GroupClosenessLocalSwaps(G, group.begin(), group.end()), std::runtime_error);
         return;
     }
@@ -2058,7 +1992,8 @@ TEST_P(CentralityGTest, testGroupClosenessLocalSwaps) {
     { // Empty input groups are not supported
         Graph G(10, isWeighted(), false);
         std::vector<node> emptyGroup;
-        EXPECT_THROW(GroupClosenessLocalSwaps(G, emptyGroup.begin(), emptyGroup.end()), std::runtime_error);
+        EXPECT_THROW(GroupClosenessLocalSwaps(G, emptyGroup.begin(), emptyGroup.end()),
+                     std::runtime_error);
     }
 
     const count k = 5;
@@ -2066,10 +2001,7 @@ TEST_P(CentralityGTest, testGroupClosenessLocalSwaps) {
     G = ConnectedComponents::extractLargestConnectedComponent(G);
 
     if (isWeighted()) {
-        G = GraphTools::toWeighted(G);
-        G.forEdges([&G](const node u, const node v) {
-            G.setWeight(u, v, Aux::Random::probability());
-        });
+        GraphTools::randomizeWeights(G);
     }
 
     auto farnessOfGroup = [&](const Graph &G, const std::unordered_set<node> &group) -> count {
@@ -2106,10 +2038,8 @@ TEST_P(CentralityGTest, testGroupClosenessLocalSwaps) {
             EXPECT_GE(sumDist, sumDistGroupMaxCC);
         } else {
             EXPECT_EQ(sumDist, sumDistGroupMaxCC);
-            std::for_each(groupMaxCC.begin(), groupMaxCC.end(), [&group](const node u) {
-                EXPECT_NE(group.find(u), group.end());
-            });
-
+            std::for_each(groupMaxCC.begin(), groupMaxCC.end(),
+                          [&group](const node u) { EXPECT_NE(group.find(u), group.end()); });
         }
     }
 }
@@ -2128,7 +2058,8 @@ TEST_P(CentralityGTest, testGroupHarmonicCloseness) {
                 if (inGroup[u])
                     group.push_back(u);
             });
-            opt = std::max(opt, GroupHarmonicCloseness::scoreOfGroup(G, group.begin(), group.end()));
+            opt =
+                std::max(opt, GroupHarmonicCloseness::scoreOfGroup(G, group.begin(), group.end()));
         } while (std::prev_permutation(inGroup.begin(), inGroup.end()));
 
         return opt;
@@ -2169,7 +2100,8 @@ TEST_P(CentralityGTest, testGroupHarmonicCloseness) {
             EXPECT_EQ(std::unordered_set<node>(group.begin(), group.end()).size(), k);
 
             // Test quality
-            const double score = GroupHarmonicCloseness::scoreOfGroup(G, group.begin(), group.end());
+            const double score =
+                GroupHarmonicCloseness::scoreOfGroup(G, group.begin(), group.end());
             const double opt = computeOpt(G, k);
             EXPECT_GE(opt, score);
             EXPECT_GE(score / opt, approxRatio);
@@ -2195,8 +2127,7 @@ TEST_P(CentralityGTest, testGroupClosenessLocalSearch) {
     Aux::Random::setSeed(1, true);
     auto G = ErdosRenyiGenerator(100, 0.1, isDirected()).generate();
     if (isWeighted()) {
-        G = GraphTools::toWeighted(G);
-        G.forEdges([&](node u, node v) { G.setWeight(u, v, Aux::Random::real(10)); });
+        GraphTools::randomizeWeights(G, std::uniform_real_distribution<edgeweight>{0, 10});
     }
 
     std::unordered_set<node> initGroup;
