@@ -1,4 +1,3 @@
-// no-networkit-format
 /*
  * Conductance.cpp
  *
@@ -10,7 +9,7 @@
 
 namespace NetworKit {
 
-double Conductance::getQuality(const Partition& zeta, const Graph& G) {
+double Conductance::getQuality(const Partition &zeta, const Graph &G) {
     double cond = 0.0;
     double denom = 0.0;
 
@@ -20,31 +19,26 @@ double Conductance::getQuality(const Partition& zeta, const Graph& G) {
         // compute denominator
         double vol[2] = {0.0, 0.0};
 
-        G.forNodes([&](node v) {
-            vol[zeta[v]] += G.weightedDegree(v);
-        });
+        G.forNodes([&](node v) { vol[zeta[v]] += G.weightedDegree(v); });
 
         // check if 2-partition
         assert(Aux::NumericTools::equal(vol[0] + vol[1], 2 * G.totalEdgeWeight()));
 
         denom = std::min(vol[0], vol[1]);
-    }
-    else {
+    } else {
         // compute denominator
         count vol[2] = {0, 0};
 
-        G.forNodes([&](node v) {
-            vol[zeta[v]] += G.degree(v);
-        });
+        G.forNodes([&](node v) { vol[zeta[v]] += G.degree(v); });
 
         // check if 2-partition
         assert(vol[0] + vol[1] == 2 * G.totalEdgeWeight());
 
-        denom = (double) std::min(vol[0], vol[1]);
+        denom = (double)std::min(vol[0], vol[1]);
     }
 
     EdgeCut ec;
-    cond = (double) ec.getQuality(zeta, G) / denom;
+    cond = (double)ec.getQuality(zeta, G) / denom;
     return cond;
 }
 
