@@ -1,4 +1,3 @@
-// no-networkit-format
 #include <cmath>
 #include <networkit/auxiliary/Log.hpp>
 #include <networkit/community/GraphClusteringTools.hpp>
@@ -15,20 +14,17 @@ float computeMaxClusterSize(const Partition &zeta) {
 } // namespace
 
 float getImbalance(const Partition &zeta) {
-    float avg = std::ceil(
-        (float)zeta.numberOfElements()
-        / (float)zeta.numberOfSubsets()); // TODO number of nodes and not number of elements
+    // TODO number of nodes and not number of elements
+    float avg = std::ceil((float)zeta.numberOfElements() / (float)zeta.numberOfSubsets());
     return computeMaxClusterSize(zeta) / avg;
 }
 
 float getImbalance(const Partition &zeta, const Graph &graph) {
-    float avg = std::ceil(
-        (float)graph.numberOfNodes()
-        / (float)zeta.numberOfSubsets());
+    float avg = std::ceil((float)graph.numberOfNodes() / (float)zeta.numberOfSubsets());
     return computeMaxClusterSize(zeta) / avg;
 }
 
-Graph communicationGraph(const Graph& graph, Partition &zeta) {
+Graph communicationGraph(const Graph &graph, Partition &zeta) {
     zeta.compact();
     count n = zeta.numberOfSubsets();
     Graph commGraph(n);
@@ -39,7 +35,7 @@ Graph communicationGraph(const Graph& graph, Partition &zeta) {
         graph.forEdges([&](node u, node v, edgeweight w) {
             if (zeta[u] != zeta[v]) {
                 commGraph.increaseWeight(zeta[u], zeta[v], w);
-                TRACE("increase weight of " , zeta[u] , " and " , zeta[v] , " by " , w);
+                TRACE("increase weight of ", zeta[u], " and ", zeta[v], " by ", w);
             }
         });
     } else {
@@ -48,7 +44,7 @@ Graph communicationGraph(const Graph& graph, Partition &zeta) {
         graph.forEdges([&](node u, node v) {
             if (zeta[u] != zeta[v]) {
                 commGraph.increaseWeight(zeta[u], zeta[v], 1);
-                TRACE("increase weight of " , zeta[u] , " and " , zeta[v] , " by 1");
+                TRACE("increase weight of ", zeta[u], " and ", zeta[v], " by 1");
             }
         });
     }
@@ -56,9 +52,7 @@ Graph communicationGraph(const Graph& graph, Partition &zeta) {
     return commGraph;
 }
 
-
-count weightedDegreeWithCluster(const Graph& graph, const Partition &zeta, node u, index cid) { //const
-//	TRACE("start wdeg with cluster...");
+count weightedDegreeWithCluster(const Graph &graph, const Partition &zeta, node u, index cid) {
     count wdeg = 0;
 
     if (graph.isWeighted()) {
@@ -67,8 +61,7 @@ count weightedDegreeWithCluster(const Graph& graph, const Partition &zeta, node
                 wdeg += w;
             }
         });
-    }
-    else {
+    } else {
         graph.forEdgesOf(u, [&](node, node v) {
             if (zeta[v] == cid) {
                 wdeg += 1;
@@ -84,7 +77,7 @@ bool isProperClustering(const Graph &G, const Partition &zeta) {
     G.forNodes([&](node v) {
         bool contained = zeta.contains(v);
         if (!contained) {
-            ERROR("Clustering does not contain node " , v);
+            ERROR("Clustering does not contain node ", v);
             success = false;
         }
     });
@@ -93,38 +86,35 @@ bool isProperClustering(const Graph &G, const Partition &zeta) {
 
 bool isOneClustering(const Graph &, const Partition &zeta) {
     return (zeta.numberOfSubsets() == 1);
-/*	index one = data[0];	// first subset id should be equal to all others
-    // TODO: use iterator forEntries and pair-wise comparison?
-    for (index e = 0; e < this->z; ++e) { // FIXME constructor initializes data with z+1, so <= is necessary. 
-        if (data[e] != one) {
-            return false;
+    /*	index one = data[0];	// first subset id should be equal to all others
+        // TODO: use iterator forEntries and pair-wise comparison?
+        for (index e = 0; e < this->z; ++e) { // FIXME constructor initializes data with z+1, so <=
+       is necessary. if (data[e] != one) { return false;
+            }
         }
-    }
-    return true;*/
+        return true;*/
 }
 
-bool isSingletonClustering(const Graph& G, const Partition& zeta) {
+bool isSingletonClustering(const Graph &G, const Partition &zeta) {
     return (zeta.numberOfSubsets() == G.numberOfNodes());
 }
 
-bool equalClusterings(const Partition& zeta, const Partition& eta, Graph& G) {
+bool equalClusterings(const Partition &zeta, const Partition &eta, Graph &G) {
     bool eq = true;
     G.parallelForEdges([&](node u, node v) {
         if (zeta.inSameSubset(u, v)) {
             if (!eta.inSameSubset(u, v)) {
                 eq = false;
             }
-        }
-        else {
+        } else {
             if (eta.inSameSubset(u, v)) {
                 eq = false;
             }
         }
-
     });
     return eq;
 }
 
-} // namespace GCT
+} // namespace GraphClusteringTools
 
 } // namespace NetworKit
