@@ -23,13 +23,13 @@ namespace NetworKit {
 
 LouvainMapEquation::LouvainMapEquation(const Graph &graph, bool hierarchical, count maxIterations,
                                        ParallelizationType parallelizationType)
-    : CommunityDetectionAlgorithm(graph), parallel(parallelizationType > ParallelizationType::None),
+    : CommunityDetectionAlgorithm(graph), parallel(parallelizationType > ParallelizationType::NONE),
       parallelizationType(parallelizationType), hierarchical(hierarchical),
       maxIterations(maxIterations), clusterCut(graph.upperNodeIdBound()),
       clusterVolume(graph.upperNodeIdBound()),
-      locks(parallelizationType == ParallelizationType::RelaxMap ? graph.upperNodeIdBound() : 0),
+      locks(parallelizationType == ParallelizationType::RELAX_MAP ? graph.upperNodeIdBound() : 0),
       nextPartition(
-          parallelizationType == ParallelizationType::Synchronous ? graph.upperNodeIdBound() : 0),
+          parallelizationType == ParallelizationType::SYNCHRONOUS ? graph.upperNodeIdBound() : 0),
       ets_neighborClusterWeights(parallel ? Aux::getMaxNumberOfThreads() : 1) {
     result = Partition(graph.upperNodeIdBound());
 }
@@ -48,7 +48,7 @@ void LouvainMapEquation::run() {
         for (node u = 0; u < G->upperNodeIdBound(); ++u) {
             if (!G->hasNode(u)) {
                 result.remove(u);
-                if (parallel && parallelizationType == ParallelizationType::Synchronous) {
+                if (parallel && parallelizationType == ParallelizationType::SYNCHRONOUS) {
                     nextPartition.remove(u);
                 }
             }
@@ -72,7 +72,7 @@ void LouvainMapEquation::run() {
         DEBUG("Map equation is ", mapEquation());
 #endif
         std::shuffle(nodes.begin(), nodes.end(), Aux::Random::getURNG());
-        if (parallelizationType == ParallelizationType::Synchronous) {
+        if (parallelizationType == ParallelizationType::SYNCHRONOUS) {
             numberOfNodesMoved = synchronousLocalMoving(nodes, iteration);
         } else {
             numberOfNodesMoved = localMoving(nodes, iteration);
@@ -369,7 +369,7 @@ bool LouvainMapEquation::performMove(node u, double degree, double loopWeight, n
                                      double weightToCurrent) {
     bool moved = true;
     if (parallel) {
-        assert(parallelizationType == ParallelizationType::RelaxMap);
+        assert(parallelizationType == ParallelizationType::RELAX_MAP);
 
         // lock currentCluster and targetCluster
         locks[std::min(currentCluster, targetCluster)].lock();
@@ -442,7 +442,7 @@ void LouvainMapEquation::runHierarchical() {
          G->numberOfNodes(), " nodes)");
 
     ParallelizationType para =
-        metaGraph.numberOfNodes() > 10000 ? parallelizationType : ParallelizationType::None;
+        metaGraph.numberOfNodes() > 10000 ? parallelizationType : ParallelizationType::NONE;
     LouvainMapEquation recursion(metaGraph, true, maxIterations, para);
     recursion.run();
     const Partition &metaPartition = recursion.getPartition();
