@@ -1,4 +1,3 @@
-// no-networkit-format
 /*
  * DynAPSP.cpp
  *
@@ -22,14 +21,14 @@
 
 namespace NetworKit {
 
-DynAPSP::DynAPSP(Graph& G) : APSP(G) {}
+DynAPSP::DynAPSP(Graph &G) : APSP(G) {}
 
 /**
  * Run method that stores a single shortest path for each node pair and stores shortest distances
  */
 void DynAPSP::run() {
     distances.resize(G.upperNodeIdBound());
-    G.parallelForNodes([&](node u){
+    G.parallelForNodes([&](node u) {
         std::unique_ptr<SSSP> sssp;
         if (G.isWeighted()) {
             sssp = std::make_unique<Dijkstra>(G, u);
@@ -39,7 +38,7 @@ void DynAPSP::run() {
         sssp->run();
         distances[u] = sssp->getDistances();
     });
-  hasRun = true;
+    hasRun = true;
 }
 
 std::vector<node> DynAPSP::getPath(node u, node v) {
@@ -60,16 +59,16 @@ std::vector<node> DynAPSP::getPath(node u, node v) {
     return path;
 }
 
-
-
 void DynAPSP::update(GraphEvent event) {
     visitedPairs = 0;
     INFO("Entering update");
     node u = event.u;
     node v = event.v;
-    edgeweight weightuv = G.weight(u,v);
-    if (!(event.type==GraphEvent::EDGE_ADDITION || (event.type==GraphEvent::EDGE_WEIGHT_INCREMENT && event.w < 0))) {
-        throw std::runtime_error("event type not allowed. Edge insertions and edge weight decreases only.");
+    edgeweight weightuv = G.weight(u, v);
+    if (!(event.type == GraphEvent::EDGE_ADDITION
+          || (event.type == GraphEvent::EDGE_WEIGHT_INCREMENT && event.w < 0))) {
+        throw std::runtime_error(
+            "event type not allowed. Edge insertions and edge weight decreases only.");
     }
     if (weightuv < distances[u][v]) {
         // initializations
@@ -82,14 +81,15 @@ void DynAPSP::update(GraphEvent event) {
         count i = 0;
         std::queue<node> bfsQ;
         std::vector<bool> visited(z, false);
-        INFO("Phase 1. distances[", u,"][", v,"] = ", distances[u][v], ", and G.weight", u,", ", v," = ",G.weight(u,v));
+        INFO("Phase 1. distances[", u, "][", v, "] = ", distances[u][v], ", and G.weight", u, ", ",
+             v, " = ", G.weight(u, v));
         distances[u][v] = weightuv;
-        if(!G.isDirected()) {
+        if (!G.isDirected()) {
             distances[v][u] = distances[u][v];
         }
         bfsQ.push(u);
         INFO("Entering bfs");
-        while (! bfsQ.empty()) {
+        while (!bfsQ.empty()) {
             node x = bfsQ.front();
             bfsQ.pop();
             DEBUG("Dequeueing node ", x);
@@ -99,7 +99,7 @@ void DynAPSP::update(GraphEvent event) {
                     DEBUG("Pushing neighbor ", w);
                     visited[w] = true;
                     source_nodes[i] = w;
-                    i ++;
+                    i++;
                 }
             });
         }
@@ -112,31 +112,34 @@ void DynAPSP::update(GraphEvent event) {
         stack.push(v);
         visited.clear();
         visited.resize(z, false);
-        while (! stack.empty()) {
+        while (!stack.empty()) {
             node y = stack.top();
             if (!visited[y]) {
-                // we leave y in the stack (so that we know when we're done visiting the subtree rooted in y)
+                // we leave y in the stack (so that we know when we're done visiting the subtree
+                // rooted in y)
                 n_sources[y] = n_sources[Pred[y]];
                 visited[y] = true;
                 for (count c = 0; c < n_sources[y]; c++) {
                     node s = source_nodes[c];
                     if (distances[s][y] > distances[s][u] + weightuv + distances[v][y]) {
                         distances[s][y] = distances[s][u] + weightuv + distances[v][y];
-                        if(!G.isDirected()) {
+                        if (!G.isDirected()) {
                             distances[y][s] = distances[s][y];
                         }
                     } else {
                         std::swap(source_nodes[c], source_nodes[n_sources[y] - 1]);
-                        c --;
-                        n_sources[y] --;
+                        c--;
+                        n_sources[y]--;
                     }
                 }
                 // adding successors of y to the stack
-                G.forNeighborsOf(y, [&](node w, edgeweight weightyw){
-                    // we go down the BFS tree rooted in v in a DFS order (the last check is necessary to make sure that (y, w) is an edge of the BFS tree rooted in v)
-                    if (visited[w] == false && distances[u][w] > distances[v][w] + weightuv && distances[v][w] == distances[v][y] + weightyw) {
+                G.forNeighborsOf(y, [&](node w, edgeweight weightyw) {
+                    // we go down the BFS tree rooted in v in a DFS order (the last check is
+                    // necessary to make sure that (y, w) is an edge of the BFS tree rooted in v)
+                    if (visited[w] == false && distances[u][w] > distances[v][w] + weightuv
+                        && distances[v][w] == distances[v][y] + weightyw) {
                         distances[u][w] = distances[v][w] + weightuv;
-                        if(!G.isDirected()) {
+                        if (!G.isDirected()) {
                             distances[w][u] = distances[u][w];
                         }
                         stack.push(w);
@@ -148,44 +151,17 @@ void DynAPSP::update(GraphEvent event) {
                 stack.pop();
             }
         }
-        // while(!Q.empty()) {
-        // 	node y = getMin();
-        // 	enqueued[y] = false;
-        // 	// update for all source nodes
-        // 	for (node x: source_nodes[Pred[y]]) {
-        // 		visitedPairs ++;
-        // 		if (distances[x][y] > distances[x][u] + distances[u][y]) {
-        // 			distances[x][y] = distances[x][u] + distances[u][y];
-        // 			if(!G.isDirected()) {
-        // 				distances[y][x] = distances[x][y];
-        // 			}
-        // 			source_nodes[y].push_back(x);
-        // 		}
-        // 	}
-        //
-        // 	G.forNeighborsOf(y, [&](node w, edgeweight weightyw){
-        // 		if (distances[u][w] > distances[u][y] + weightyw && distances[v][w] == distances[v][y] + weightyw) { // I also check that y was a predecessor for w in the s.p. from v
-        // 			distances[u][w] = distances[u][y] + weightyw;
-        // 			Pred[w] = y;
-        // 			if(!G.isDirected()) {
-        // 				distances[w][u] = distances[u][w];
-        // 			}
-        // 			updateQueue(w, distances[u][w]);
-        // 		}
-        // 	});
-        // }
     }
 }
 
-void DynAPSP::updateBatch(const std::vector<GraphEvent>& batch) {
-  for(auto e : batch){
-    update(e);
-  }
+void DynAPSP::updateBatch(const std::vector<GraphEvent> &batch) {
+    for (auto e : batch) {
+        update(e);
+    }
 }
 
 count DynAPSP::visPairs() {
     return visitedPairs;
 }
 
-
 } /* namespace NetworKit */
