@@ -1,10 +1,9 @@
-// no-networkit-format
 /*
-*  EffectiveDiameter.cpp
-*
-*  Created on: 16.06.2014
-*      Author: Marc Nemes
-*/
+ *  EffectiveDiameter.cpp
+ *
+ *  Created on: 16.06.2014
+ *      Author: Marc Nemes
+ */
 
 #include <cmath>
 #include <omp.h>
@@ -15,11 +14,15 @@
 
 namespace NetworKit {
 
-EffectiveDiameter::EffectiveDiameter(const Graph& G, const double ratio) : Algorithm(), G(&G), ratio(ratio) {
-    if (G.isDirected()) throw std::runtime_error("current implementation can only deal with undirected graphs");
+EffectiveDiameter::EffectiveDiameter(const Graph &G, const double ratio)
+    : Algorithm(), G(&G), ratio(ratio) {
+    if (G.isDirected())
+        throw std::runtime_error("current implementation can only deal with undirected graphs");
     ConnectedComponents cc(G);
     cc.run();
-    if (cc.numberOfComponents() > 1) throw std::runtime_error("current implementation only runs on graphs with 1 connected component");
+    if (cc.numberOfComponents() > 1)
+        throw std::runtime_error(
+            "current implementation only runs on graphs with 1 connected component");
 }
 
 void EffectiveDiameter::run() {
@@ -38,7 +41,7 @@ void EffectiveDiameter::run() {
     std::vector<node> activeNodes;
 
     // initialize all nodes
-    G->forNodes([&](node v){
+    G->forNodes([&](node v) {
         std::vector<bool> connectedNodes;
         // initialize n entries with value 0
         connectedNodes.assign(z, 0);
@@ -53,40 +56,42 @@ void EffectiveDiameter::run() {
     while (!activeNodes.empty()) {
         for (count x = 0; x < activeNodes.size(); x++) {
             node v = activeNodes[x];
-                mCurr[v] = mPrev[v];
-                G->forNeighborsOf(v, [&](node u) {
-                    for (count i = 0; i < G->numberOfNodes(); i++) {
-                        // add the current neighbor of u to the neighborhood of v
-                        mCurr[v][i] = mCurr[v][i] || mPrev[u][i];
-                    }
-                });
-
-                // compute the number of connected nodes
-                count numConnectedNodes = 0;
+            mCurr[v] = mPrev[v];
+            G->forNeighborsOf(v, [&](node u) {
                 for (count i = 0; i < G->numberOfNodes(); i++) {
-                    if (mCurr[v][i] == 1) {
-                        numConnectedNodes++;
-                    }
+                    // add the current neighbor of u to the neighborhood of v
+                    mCurr[v][i] = mCurr[v][i] || mPrev[u][i];
                 }
+            });
 
-                // when the number of connected nodes surpasses the threshold the node must no longer be considered
-                if (numConnectedNodes >= threshold) {
-                    effectiveDiameter += h;
-                    // remove the current node from future iterations
-                    std::swap(activeNodes[x], activeNodes.back());
-                    activeNodes.pop_back();
-                    --x; //don't skip former activeNodes.back() that has been switched to activeNodes[x]
+            // compute the number of connected nodes
+            count numConnectedNodes = 0;
+            for (count i = 0; i < G->numberOfNodes(); i++) {
+                if (mCurr[v][i] == 1) {
+                    numConnectedNodes++;
                 }
             }
-            mPrev = mCurr;
-            h++;
+
+            // when the number of connected nodes surpasses the threshold the node must no longer be
+            // considered
+            if (numConnectedNodes >= threshold) {
+                effectiveDiameter += h;
+                // remove the current node from future iterations
+                std::swap(activeNodes[x], activeNodes.back());
+                activeNodes.pop_back();
+                --x; // don't skip former activeNodes.back() that has been switched to
+                     // activeNodes[x]
+            }
+        }
+        mPrev = mCurr;
+        h++;
     }
     effectiveDiameter /= G->numberOfNodes();
     hasRun = true;
 }
 
 double EffectiveDiameter::getEffectiveDiameter() const {
-    if(!hasRun) {
+    if (!hasRun) {
         throw std::runtime_error("Call run()-function first.");
     }
     return effectiveDiameter;
