@@ -1,12 +1,12 @@
-// no-networkit-format
-#include <networkit/graph/RandomMaximumSpanningForest.hpp>
-#include <networkit/auxiliary/SignalHandling.hpp>
 #include <networkit/auxiliary/Parallel.hpp>
+#include <networkit/auxiliary/SignalHandling.hpp>
 #include <networkit/graph/GraphTools.hpp>
+#include <networkit/graph/RandomMaximumSpanningForest.hpp>
 
 namespace NetworKit {
 
-RandomMaximumSpanningForest::RandomMaximumSpanningForest(const Graph &G) : G(G), hasWeightedEdges(false), hasMSF(false), hasAttribute(false) { }
+RandomMaximumSpanningForest::RandomMaximumSpanningForest(const Graph &G)
+    : G(G), hasWeightedEdges(false), hasMSF(false), hasAttribute(false) {}
 
 void RandomMaximumSpanningForest::run() {
     hasRun = false;
@@ -72,7 +72,9 @@ void RandomMaximumSpanningForest::run() {
 }
 
 bool RandomMaximumSpanningForest::inMSF(edgeid eid) const {
-    if (!hasAttribute) throw std::runtime_error("Error: Either the attribute hasn't be calculated yet or the graph has no edge ids.");
+    if (!hasAttribute)
+        throw std::runtime_error(
+            "Error: Either the attribute hasn't be calculated yet or the graph has no edge ids.");
 
     return msfAttribute[eid];
 }
@@ -87,10 +89,11 @@ bool RandomMaximumSpanningForest::inMSF(node u, node v) const {
     }
 }
 
-std::vector< bool > RandomMaximumSpanningForest::getAttribute(bool move) {
+std::vector<bool> RandomMaximumSpanningForest::getAttribute(bool move) {
     std::vector<bool> result;
 
-    if (!hasAttribute) throw std::runtime_error("Error: The run() method must be executed first");
+    if (!hasAttribute)
+        throw std::runtime_error("Error: The run() method must be executed first");
 
     if (move) {
         result = std::move(msfAttribute);
@@ -105,7 +108,8 @@ std::vector< bool > RandomMaximumSpanningForest::getAttribute(bool move) {
 Graph RandomMaximumSpanningForest::getMSF(bool move) {
     Graph result;
 
-    if (!hasMSF) throw std::runtime_error("Error: The run() method must be executed first");
+    if (!hasMSF)
+        throw std::runtime_error("Error: The run() method must be executed first");
 
     if (move) {
         result = std::move(msf);
