@@ -1,4 +1,3 @@
-// no-networkit-format
 
 #include <networkit/auxiliary/Parallel.hpp>
 #include <networkit/auxiliary/SignalHandling.hpp>
@@ -7,12 +6,13 @@
 
 namespace NetworKit {
 
-UnionMaximumSpanningForest::UnionMaximumSpanningForest(const Graph &G) : G(&G), hasWeightedEdges(false), hasUMSF(false), hasAttribute(false) {}
+UnionMaximumSpanningForest::UnionMaximumSpanningForest(const Graph &G)
+    : G(&G), hasWeightedEdges(false), hasUMSF(false), hasAttribute(false) {}
 
 void UnionMaximumSpanningForest::run() {
     hasRun = false;
     hasUMSF = false;
-    hasAttribute= false;
+    hasAttribute = false;
 
     Aux::SignalHandler handler;
 
@@ -49,7 +49,7 @@ void UnionMaximumSpanningForest::run() {
 
     edgeweight currentAttribute = std::numeric_limits<edgeweight>::max();
 
-    std::vector<std::pair<node, node> > nodesToMerge;
+    std::vector<std::pair<node, node>> nodesToMerge;
     UnionFind uf(G->upperNodeIdBound());
 
     for (weightedEdge e : weightedEdges) {
@@ -62,7 +62,6 @@ void UnionMaximumSpanningForest::run() {
             currentAttribute = e.attribute;
         }
 
-
         if (uf.find(e.u) != uf.find(e.v)) {
             if (useEdgeWeights) {
                 umsf.addEdge(e.u, e.v, e.attribute);
@@ -75,7 +74,6 @@ void UnionMaximumSpanningForest::run() {
             }
 
             nodesToMerge.emplace_back(e.u, e.v);
-
         }
     }
 
@@ -87,7 +85,9 @@ void UnionMaximumSpanningForest::run() {
 }
 
 bool UnionMaximumSpanningForest::inUMSF(edgeid eid) const {
-    if (!hasAttribute) throw std::runtime_error("Error: Either the attribute hasn't be calculated yet or the graph has no edge ids.");
+    if (!hasAttribute)
+        throw std::runtime_error(
+            "Error: Either the attribute hasn't be calculated yet or the graph has no edge ids.");
 
     return umsfAttribute[eid];
 }
@@ -102,10 +102,11 @@ bool UnionMaximumSpanningForest::inUMSF(node u, node v) const {
     }
 }
 
-std::vector< bool > UnionMaximumSpanningForest::getAttribute(bool move) {
+std::vector<bool> UnionMaximumSpanningForest::getAttribute(bool move) {
     std::vector<bool> result;
 
-    if (!hasAttribute) throw std::runtime_error("Error: The run() method must be executed first");
+    if (!hasAttribute)
+        throw std::runtime_error("Error: The run() method must be executed first");
 
     if (move) {
         result = std::move(umsfAttribute);
@@ -120,7 +121,8 @@ std::vector< bool > UnionMaximumSpanningForest::getAttribute(bool move) {
 Graph UnionMaximumSpanningForest::getUMSF(bool move) {
     Graph result;
 
-    if (!hasUMSF) throw std::runtime_error("Error: The run() method must be executed first");
+    if (!hasUMSF)
+        throw std::runtime_error("Error: The run() method must be executed first");
 
     if (move) {
         result = std::move(umsf);
