@@ -1,4 +1,3 @@
-// no-networkit-format
 /*
  * GraphBuilderAutoCompleteGTest.cpp
  *
@@ -11,22 +10,22 @@
 #include <algorithm>
 #include <tuple>
 
+#include <networkit/auxiliary/Parallel.hpp>
+#include <networkit/auxiliary/Random.hpp>
 #include <networkit/graph/Graph.hpp>
 #include <networkit/graph/GraphBuilder.hpp>
 #include <networkit/graph/GraphTools.hpp>
-#include <networkit/auxiliary/Random.hpp>
-#include <networkit/auxiliary/Parallel.hpp>
 
 namespace NetworKit {
 
-class GraphBuilderAutoCompleteGTest: public testing::TestWithParam< std::tuple<bool, bool, bool> > {
+class GraphBuilderAutoCompleteGTest : public testing::TestWithParam<std::tuple<bool, bool, bool>> {
 public:
     virtual void SetUp();
 
 protected:
     GraphBuilder bHouse;
-    std::vector< std::pair<node, node> > houseEdgesOut;
-    std::vector< std::vector<edgeweight> > Ahouse;
+    std::vector<std::pair<node, node>> houseEdgesOut;
+    std::vector<std::vector<edgeweight>> Ahouse;
     count n_house;
     count m_house;
 
@@ -40,20 +39,17 @@ protected:
     bool useParallel() const;
 
     GraphBuilder createGraphBuilder(count n = 0) const;
-    Graph toGraph(GraphBuilder& b) const;
+    Graph toGraph(GraphBuilder &b) const;
 };
 
-INSTANTIATE_TEST_SUITE_P(InstantiationName, GraphBuilderAutoCompleteGTest, testing::Values(
-    std::make_tuple(false, false, false), // weighted, directed, parallel
-    std::make_tuple(true, false, false),
-    std::make_tuple(false, true, false),
-    std::make_tuple(true, true, false),
+INSTANTIATE_TEST_SUITE_P(
+    InstantiationName, GraphBuilderAutoCompleteGTest,
+    testing::Values(std::make_tuple(false, false, false), // weighted, directed, parallel
+                    std::make_tuple(true, false, false), std::make_tuple(false, true, false),
+                    std::make_tuple(true, true, false),
 
-    std::make_tuple(false, false, true),
-    std::make_tuple(true, false, true),
-    std::make_tuple(false, true, true),
-    std::make_tuple(true, true, true)
-));
+                    std::make_tuple(false, false, true), std::make_tuple(true, false, true),
+                    std::make_tuple(false, true, true), std::make_tuple(true, true, true)));
 
 bool GraphBuilderAutoCompleteGTest::isWeighted() const {
     return std::get<0>(GetParam());
@@ -70,7 +66,7 @@ GraphBuilder GraphBuilderAutoCompleteGTest::createGraphBuilder(count n) const {
     return GraphBuilder(n, isWeighted(), isDirected());
 }
 
-Graph GraphBuilderAutoCompleteGTest::toGraph(GraphBuilder& b) const {
+Graph GraphBuilderAutoCompleteGTest::toGraph(GraphBuilder &b) const {
     return b.completeGraph(useParallel());
 }
 
@@ -94,19 +90,10 @@ void GraphBuilderAutoCompleteGTest::SetUp() {
     m_house = 8;
 
     bHouse = createGraphBuilder(5);
-    houseEdgesOut = {
-        {3, 1},
-        {1, 0},
-        {0, 2},
-        {2, 1},
-        {1, 4},
-        {4, 3},
-        {3, 2},
-        {2, 4}
-    };
+    houseEdgesOut = {{3, 1}, {1, 0}, {0, 2}, {2, 1}, {1, 4}, {4, 3}, {3, 2}, {2, 4}};
     Ahouse = {n_house, std::vector<edgeweight>(n_house, 0.0)};
     edgeweight ew = 1.0;
-    for (auto& e : houseEdgesOut) {
+    for (auto &e : houseEdgesOut) {
         node u = e.first;
         node v = e.second;
         bHouse.addHalfOutEdge(u, v, ew);
@@ -154,7 +141,6 @@ TEST_P(GraphBuilderAutoCompleteGTest, testAddNode) {
     ASSERT_FALSE(G.isEmpty());
 }
 
-
 /** NODE PROPERTIES **/
 
 TEST_P(GraphBuilderAutoCompleteGTest, testDegree) {
@@ -208,7 +194,6 @@ TEST_P(GraphBuilderAutoCompleteGTest, testDegreeOut) {
     }
 }
 
-
 /** EDGE MODIFIERS **/
 
 TEST_P(GraphBuilderAutoCompleteGTest, testAddHalfEdge) {
@@ -262,7 +247,6 @@ TEST_P(GraphBuilderAutoCompleteGTest, testAddHalfEdge) {
     }
 }
 
-
 /** GLOBAL PROPERTIES **/
 
 TEST_P(GraphBuilderAutoCompleteGTest, testIsWeighted) {
@@ -291,7 +275,6 @@ TEST_P(GraphBuilderAutoCompleteGTest, testUpperNodeIdBound) {
     ASSERT_EQ(5u, Ghouse.upperNodeIdBound());
 }
 
-
 /** EDGE ATTRIBUTES **/
 
 TEST_P(GraphBuilderAutoCompleteGTest, testSetWeight) {
@@ -339,7 +322,8 @@ TEST_P(GraphBuilderAutoCompleteGTest, testSetWeight) {
             ASSERT_EQ(2.718, G.weight(3, 4));
             ASSERT_EQ(5.243, G.weight(4, 3));
         } else {
-            // we have actually 2 edges in both direction. It is not defined which weight is returned.
+            // we have actually 2 edges in both direction. It is not defined which weight is
+            // returned.
             ASSERT_TRUE(G.weight(3, 4) == 2.718 || G.weight(3, 4) == 5.243);
             ASSERT_TRUE(G.weight(4, 3) == 2.718 || G.weight(4, 3) == 5.243);
         }
@@ -349,7 +333,6 @@ TEST_P(GraphBuilderAutoCompleteGTest, testSetWeight) {
     }
 }
 
-
 /** toGraph **/
 
 TEST_P(GraphBuilderAutoCompleteGTest, testSameAsGraph) {
@@ -367,14 +350,16 @@ TEST_P(GraphBuilderAutoCompleteGTest, testSameAsGraph) {
 
         G_expected.forNodes([&](node v) {
             double p = Aux::Random::probability();
-            // if we change edges we have to keep in mind, that GraphBuilder is designed to keep only half-edges.
-            // e.g. if we have already added an edge v -> u, changing the weight of u -> v might create a new edge in the builder but change the existing edge in G_expected (does not apply for directed graphs)
+            // if we change edges we have to keep in mind, that GraphBuilder is designed to keep
+            // only half-edges. e.g. if we have already added an edge v -> u, changing the weight of
+            // u -> v might create a new edge in the builder but change the existing edge in
+            // G_expected (does not apply for directed graphs)
 
             if (p < 0.1) { // new node
                 n++;
                 b.addNode();
                 G_expected.addNode();
-            } else { // new edge
+            } else {                                     // new edge
                 node u = Aux::Random::integer(v, n - 1); // self-loops possible
                 edgeweight ew = Aux::Random::probability();
                 b.addHalfEdge(v, u, ew);
@@ -409,8 +394,8 @@ TEST_P(GraphBuilderAutoCompleteGTest, testSameAsGraph) {
             ASSERT_EQ(G_expected.degreeIn(v), G_actual.degreeIn(v));
             ASSERT_EQ(G_expected.degreeOut(v), G_actual.degreeOut(v));
             ASSERT_NEAR(G_expected.weightedDegree(v), G_actual.weightedDegree(v), epsilon);
-            ASSERT_NEAR(G_expected.weightedDegree(v, true),
-                        G_actual.weightedDegree(v, true), epsilon);
+            ASSERT_NEAR(G_expected.weightedDegree(v, true), G_actual.weightedDegree(v, true),
+                        epsilon);
         });
         G_expected.forEdges([&](node u, node v, edgeweight ew) {
             ASSERT_TRUE(G_actual.hasEdge(u, v));
@@ -418,12 +403,8 @@ TEST_P(GraphBuilderAutoCompleteGTest, testSameAsGraph) {
         });
 
         // make sure that G_actual has not more nodes/edges than G_expected
-        G_actual.forNodes([&](node v) {
-            ASSERT_TRUE(G_expected.hasNode(v));
-        });
-        G_actual.forEdges([&](node u, node v) {
-            ASSERT_TRUE(G_expected.hasEdge(u, v));
-        });
+        G_actual.forNodes([&](node v) { ASSERT_TRUE(G_expected.hasNode(v)); });
+        G_actual.forEdges([&](node u, node v) { ASSERT_TRUE(G_expected.hasEdge(u, v)); });
     }
 }
 
@@ -435,9 +416,7 @@ TEST_P(GraphBuilderAutoCompleteGTest, testForValidStateAfterToGraph) {
     ASSERT_EQ(0u, this->bHouse.upperNodeIdBound());
     ASSERT_EQ(isWeighted(), this->bHouse.isWeighted());
     ASSERT_EQ(isDirected(), this->bHouse.isDirected());
-    this->bHouse.forNodes([&](node) {
-        FAIL();
-    });
+    this->bHouse.forNodes([&](node) { FAIL(); });
 
     Graph G1 = toGraph(this->bHouse);
     ASSERT_TRUE(G1.isEmpty());
@@ -484,9 +463,7 @@ TEST_P(GraphBuilderAutoCompleteGTest, testForNodes) {
 
 TEST_P(GraphBuilderAutoCompleteGTest, testParallelForNodes) {
     std::vector<node> visited(bHouse.upperNodeIdBound());
-    this->bHouse.parallelForNodes([&](node u) {
-        visited[u] = u;
-    });
+    this->bHouse.parallelForNodes([&](node u) { visited[u] = u; });
 
     Aux::Parallel::sort(visited.begin(), visited.end());
 
@@ -500,7 +477,7 @@ TEST_P(GraphBuilderAutoCompleteGTest, testForNodePairs) {
     count n = 10;
     auto b = createGraphBuilder(n);
 
-    std::vector< std::vector<bool> > visited(n, std::vector<bool>(n, false));
+    std::vector<std::vector<bool>> visited(n, std::vector<bool>(n, false));
     b.forNodePairs([&](node u, node v) {
         if (visited[u][v] || visited[v][u]) {
             FAIL();
@@ -524,7 +501,7 @@ TEST_P(GraphBuilderAutoCompleteGTest, testParallelForNodePairs) {
     count n = 10;
     auto b = createGraphBuilder(n);
 
-    std::vector< std::vector<bool> > visited(n, std::vector<bool>(n, false));
+    std::vector<std::vector<bool>> visited(n, std::vector<bool>(n, false));
     b.forNodePairs([&](node u, node v) {
         if (visited[u][v]) {
             FAIL();
