@@ -10,6 +10,7 @@
 #include <gtest/gtest.h>
 
 #include <networkit/auxiliary/Random.hpp>
+#include <networkit/generators/DorogovtsevMendesGenerator.hpp>
 #include <networkit/generators/ErdosRenyiGenerator.hpp>
 #include <networkit/graph/Graph.hpp>
 #include <networkit/graph/GraphTools.hpp>
@@ -19,7 +20,6 @@ namespace NetworKit {
 
 class GraphToolsGTest : public testing::TestWithParam<std::pair<bool, bool>> {
 protected:
-    Graph generateRandomWeights(const Graph &G) const;
     bool weighted() const noexcept;
     bool directed() const noexcept;
 };
@@ -28,12 +28,6 @@ INSTANTIATE_TEST_SUITE_P(InstantiationName, GraphToolsGTest,
                          testing::Values(std::make_pair(false, false), std::make_pair(true, false),
                                          std::make_pair(false, true), std::make_pair(true, true)));
 
-Graph GraphToolsGTest::generateRandomWeights(const Graph &G) const {
-    Graph Gw(G, true, G.isDirected());
-    Gw.forEdges([&](node u, node v) { Gw.setWeight(u, v, Aux::Random::probability()); });
-    return Gw;
-}
-
 bool GraphToolsGTest::weighted() const noexcept {
     return GetParam().first;
 }
@@ -57,7 +51,7 @@ TEST_P(GraphToolsGTest, testSize) {
         Aux::Random::setSeed(seed, false);
         auto G = ErdosRenyiGenerator(n, p, directed()).generate();
         if (weighted()) {
-            G = generateRandomWeights(G);
+            GraphTools::randomizeWeights(G);
         }
 
         doTest(G);
@@ -88,7 +82,7 @@ TEST_P(GraphToolsGTest, testDensity) {
         Aux::Random::setSeed(seed, false);
         auto G = ErdosRenyiGenerator(n, p, directed()).generate();
         if (weighted()) {
-            G = generateRandomWeights(G);
+            GraphTools::randomizeWeights(G);
         }
 
         doTest(G);
@@ -133,7 +127,7 @@ TEST_P(GraphToolsGTest, testVolume) {
         Aux::Random::setSeed(seed, false);
         auto G = ErdosRenyiGenerator(n, p, directed()).generate();
         if (weighted()) {
-            G = generateRandomWeights(G);
+            GraphTools::randomizeWeights(G);
         }
 
         doTest(G);
@@ -174,7 +168,7 @@ TEST_P(GraphToolsGTest, testMaxDegree) {
         Aux::Random::setSeed(seed, false);
         auto G = ErdosRenyiGenerator(n, p, directed()).generate();
         if (weighted()) {
-            G = generateRandomWeights(G);
+            GraphTools::randomizeWeights(G);
         }
 
         doTest(G);
@@ -855,9 +849,16 @@ TEST_P(GraphToolsGTest, testToUndirected) {
     constexpr double p = 0.2;
 
     auto testGraphs = [&](const Graph &G, const Graph &G1) {
+        // we need this because we lose edges due to some nodes having both an in edge and an out
+        // edge to the same node.
+        count edgesLost = 0;
+        if (G.isDirected())
+            edgesLost = G.parallelSumForEdges(
+                [&](node u, node v) { return (u != v && G.hasEdge(v, u)) ? 1 : 0; });
+
         EXPECT_EQ(G.numberOfNodes(), G1.numberOfNodes());
         EXPECT_EQ(G.upperNodeIdBound(), G1.upperNodeIdBound());
-        EXPECT_EQ(G.numberOfEdges(), G1.numberOfEdges());
+        EXPECT_EQ(G.numberOfEdges() - edgesLost, G1.numberOfEdges());
         EXPECT_EQ(G.upperEdgeIdBound(), G1.upperEdgeIdBound());
         EXPECT_EQ(G.isWeighted(), G1.isWeighted());
         EXPECT_NE(G.isDirected(), G1.isDirected());
@@ -865,7 +866,8 @@ TEST_P(GraphToolsGTest, testToUndirected) {
 
         G.forEdges([&](node u, node v, edgeweight w) {
             EXPECT_TRUE(G1.hasEdge(u, v));
-            EXPECT_DOUBLE_EQ(G1.weight(u, v), w);
+            EXPECT_DOUBLE_EQ(G1.weight(u, v),
+                             !G.isDirected() || !weighted() ? w : w + G.weight(v, u));
         });
     };
 
@@ -873,7 +875,7 @@ TEST_P(GraphToolsGTest, testToUndirected) {
         Aux::Random::setSeed(seed, false);
         auto G = ErdosRenyiGenerator(n, p, true).generate();
         if (weighted()) {
-            G = generateRandomWeights(G);
+            GraphTools::randomizeWeights(G);
         }
         auto G1 = GraphTools::toUndirected(G);
         testGraphs(G, G1);
@@ -906,7 +908,7 @@ TEST_P(GraphToolsGTest, testToUnWeighted) {
         auto G1 = GraphTools::toWeighted(G);
         testGraphs(G, G1);
 
-        G = generateRandomWeights(G);
+        GraphTools::randomizeWeights(G);
         G1 = GraphTools::toUnweighted(G);
         testGraphs(G, G1);
     }
@@ -945,8 +947,8 @@ TEST_P(GraphToolsGTest, testAppend) {
         auto G2 = ErdosRenyiGenerator(n2, p2, directed()).generate();
 
         if (weighted()) {
-            G1 = generateRandomWeights(G1);
-            G2 = generateRandomWeights(G2);
+            GraphTools::randomizeWeights(G1);
+            GraphTools::randomizeWeights(G2);
         }
 
         auto G(G1);
@@ -989,8 +991,8 @@ TEST_P(GraphToolsGTest, testMerge) {
         auto G1 = ErdosRenyiGenerator(n2, p2, directed()).generate();
 
         if (weighted()) {
-            Gorig = generateRandomWeights(Gorig);
-            G1 = generateRandomWeights(G1);
+            GraphTools::randomizeWeights(Gorig);
+            GraphTools::randomizeWeights(G1);
         }
 
         auto Gmerge(Gorig);
@@ -1027,8 +1029,7 @@ TEST_P(GraphToolsGTest, testEdgesSortedByWeight) {
         auto G = METISGraphReader{}.read("input/PGPgiantcompo.graph");
 
         if (weighted()) {
-            G = GraphTools::toWeighted(G);
-            G.forEdges([&G](node u, node v) { G.setWeight(u, v, Aux::Random::real(10)); });
+            GraphTools::randomizeWeights(G, std::uniform_real_distribution<edgeweight>{0, 10});
         }
 
         GraphTools::sortEdgesByWeight(G);
@@ -1039,4 +1040,41 @@ TEST_P(GraphToolsGTest, testEdgesSortedByWeight) {
         EXPECT_TRUE(G.checkConsistency());
     }
 }
+
+TEST_P(GraphToolsGTest, testEdgesRandomizer) {
+    if (!weighted())
+        return;
+    Aux::Random::setSeed(1, true);
+    Graph G1 = ErdosRenyiGenerator{2000, 0.3, directed()}.generate();
+    Graph G(G1, true, directed());
+    GraphTools::randomizeWeights(G);
+    edgeweight sum = G.parallelSumForEdges([&](node, node, edgeweight ew) { return ew; });
+    edgeweight average = sum / G.numberOfEdges();
+    edgeweight squareDiffSum = G.parallelSumForEdges(
+        [&](node, node, edgeweight ew) { return (ew - average) * (ew - average); });
+    // since we have a uniform distribution  between 0 and 1 the variance is 1/12
+    EXPECT_NEAR(1.0 / 12.0, squareDiffSum / G.numberOfEdges(), 1e-2);
+    EXPECT_NEAR(0.5, average, 1e-3);
+    if (!directed())
+        G.forEdges([&G](node u, node v) { EXPECT_EQ(G.weight(u, v), G.weight(v, u)); });
+    else
+        G.forNodes([&G](node u) {
+            G.forInEdgesOf(u,
+                           [&](node u, node v, edgeweight ew) { EXPECT_EQ(G.weight(v, u), ew); });
+        });
+}
+
+TEST_P(GraphToolsGTest, testEdgesRandomizerDeterminism) {
+    if (!weighted())
+        return;
+    Aux::Random::setSeed(1, true);
+    Graph G1 = ErdosRenyiGenerator{2000, 0.3, directed()}.generate();
+    Graph Ga(G1, true, directed());
+    Graph Gb(G1, true, directed());
+    Aux::Random::setSeed(1, true);
+    GraphTools::randomizeWeights(Ga);
+    Aux::Random::setSeed(1, true);
+    GraphTools::randomizeWeights(Gb);
+    Ga.forEdges([&Ga, &Gb](node u, node v) { EXPECT_EQ(Ga.weight(u, v), Gb.weight(u, v)); });
+}
 } // namespace NetworKit
