@@ -1,17 +1,17 @@
-// no-networkit-format
 #include <fstream>
 
 #include <networkit/io/BinaryEdgeListPartitionWriter.hpp>
 
 namespace NetworKit {
 
-BinaryEdgeListPartitionWriter::BinaryEdgeListPartitionWriter(node firstNode, uint8_t width) : firstNode(firstNode), width(width) {
+BinaryEdgeListPartitionWriter::BinaryEdgeListPartitionWriter(node firstNode, uint8_t width)
+    : firstNode(firstNode), width(width) {
     if (width != 4 && width != 8) {
         throw std::runtime_error("Width must be 4 or 8");
     }
 }
 
-void BinaryEdgeListPartitionWriter::write( Partition &zeta, const std::string &path ) const {
+void BinaryEdgeListPartitionWriter::write(Partition &zeta, const std::string &path) const {
     auto write_little_endian = [](std::ofstream &os, index x, uint8_t width) {
         for (uint8_t w = 0; w < width; ++w) {
             os.put(uint8_t(x));
@@ -20,7 +20,9 @@ void BinaryEdgeListPartitionWriter::write( Partition &zeta, const std::string &p
     };
 
     if (width == 4 && zeta.upperBound() > std::numeric_limits<uint32_t>::max()) {
-        throw std::runtime_error("Error, the upper bound of the given partition cannot be represented by an unsigned int of width 4. Please use a width of 8.");
+        throw std::runtime_error(
+            "Error, the upper bound of the given partition cannot be represented by an unsigned "
+            "int of width 4. Please use a width of 8.");
     }
 
     std::ofstream os(path, std::ios::trunc | std::ios::binary);
