@@ -1,4 +1,3 @@
-// no-networkit-format
 #include <fstream>
 
 #include <networkit/io/BinaryPartitionWriter.hpp>
@@ -13,7 +12,9 @@ BinaryPartitionWriter::BinaryPartitionWriter(uint8_t width) : width(width) {
 
 void BinaryPartitionWriter::write(const Partition &zeta, const std::string &path) const {
     if (width == 4 && zeta.upperBound() > std::numeric_limits<uint32_t>::max()) {
-        throw std::runtime_error("Error, the upper bound of the given partition cannot be represented by an unsigned int of width 4. Please use a width of 8.");
+        throw std::runtime_error(
+            "Error, the upper bound of the given partition cannot be represented by an unsigned "
+            "int of width 4. Please use a width of 8.");
     }
 
     std::ofstream os(path, std::ios::trunc | std::ios::binary);
