@@ -1,4 +1,3 @@
-// no-networkit-format
 /*
  * DotWriter.cpp
  *
@@ -16,9 +15,7 @@ void DotGraphWriter::write(const Graph &G, const std::string &path) {
     std::ofstream file{path};
 
     file << "graph {\n";
-    G.forEdges([&](node u, node v){
-        file << u << " -- " << v << ";\n";
-    });
+    G.forEdges([&](node u, node v) { file << u << " -- " << v << ";\n"; });
     file << "}\n";
 }
 
