@@ -1,4 +1,3 @@
-// no-networkit-format
 #include <fstream>
 #include <unordered_set>
 
@@ -6,10 +5,10 @@
 
 namespace NetworKit {
 
-std::map<index, double> DotPartitionWriter::createHueMap(Graph &graph, Partition& zeta) const {
+std::map<index, double> DotPartitionWriter::createHueMap(Graph &graph, Partition &zeta) const {
     std::unordered_set<index> uniqueIds;
 
-    graph.forNodes([&](node u){
+    graph.forNodes([&](node u) {
         if (graph.degree(u) == 0) {
             return;
         }
@@ -21,7 +20,7 @@ std::map<index, double> DotPartitionWriter::createHueMap(Graph &graph, Partition
 
     int idx = 0;
     double factor = 1.0 / uniqueIds.size();
-    for(const auto& value: uniqueIds) {
+    for (const auto &value : uniqueIds) {
         clusterHueMap.insert(std::make_pair(value, factor * idx));
         ++idx;
     }
@@ -36,7 +35,7 @@ void DotPartitionWriter::write(Graph &graph, Partition &zeta, const std::string
 
     file << "graph {\n";
 
-    graph.forNodes([&](node u){
+    graph.forNodes([&](node u) {
         if (graph.degree(u) == 0) {
             return;
         }
@@ -44,9 +43,7 @@ void DotPartitionWriter::write(Graph &graph, Partition &zeta, const std::string
         double h = hueMap.at(c);
         file << u << " [style=filled, color=\"" << h << ",0.99,0.99\", label=" << c << "];\n";
     });
-    graph.forEdges([&](node u, node v){
-        file << u << " -- " << v << ";\n";
-    });
+    graph.forEdges([&](node u, node v) { file << u << " -- " << v << ";\n"; });
 
     file << "}\n";
 }
