@@ -1,4 +1,3 @@
-// no-networkit-format
 /*
  * EdgeListPartitionReader.cpp
  *
@@ -10,8 +9,8 @@
 
 namespace NetworKit {
 
-EdgeListPartitionReader::EdgeListPartitionReader(node firstNode, char sepChar) : firstNode(firstNode), sepChar(sepChar) {
-}
+EdgeListPartitionReader::EdgeListPartitionReader(node firstNode, char sepChar)
+    : firstNode(firstNode), sepChar(sepChar) {}
 
 Partition EdgeListPartitionReader::read(const std::string &path) {
     std::ifstream file(path);
@@ -24,7 +23,7 @@ Partition EdgeListPartitionReader::read(const std::string &path) {
     std::string line;
     index newOmega = 0;
     Partition zeta(0); // start without nodes
-    while(std::getline(file, line)) {
+    while (std::getline(file, line)) {
         std::vector<std::string> split = Aux::StringTools::split(line, sepChar);
         if (split[0] != "#") {
             index c = std::atoi(split[1].c_str());
@@ -40,7 +39,7 @@ Partition EdgeListPartitionReader::read(const std::string &path) {
         }
     }
 
-    zeta.setUpperBound(newOmega+1);
+    zeta.setUpperBound(newOmega + 1);
     return zeta;
 }
 
