@@ -1,4 +1,3 @@
-// no-networkit-format
 /*
  * RasterReader.cpp
  *
@@ -15,10 +14,9 @@
 
 namespace NetworKit {
 
-RasterReader::RasterReader(double normalizationFactor): normalizationFactor(normalizationFactor) {}
+RasterReader::RasterReader(double normalizationFactor) : normalizationFactor(normalizationFactor) {}
 
-std::pair<std::vector<double>, std::vector<double>>
-RasterReader::read(const std::string& path) {
+std::pair<std::vector<double>, std::vector<double>> RasterReader::read(const std::string &path) {
     DEBUG("start reading raster file...");
 
     std::ifstream file(path);
@@ -35,7 +33,7 @@ RasterReader::read(const std::string& path) {
     auto it = line.begin() + 14; // ignore the first 14 characters
     auto end = line.end();
     std::tie(val, it) = Aux::Parsing::strTo<double>(it, end);
-    uint64_t ncols = (uint64_t) val;
+    uint64_t ncols = (uint64_t)val;
     DEBUG("line: ", line, "; nrows: ", ncols);
 
     // ** read number of rows
@@ -43,7 +41,7 @@ RasterReader::read(const std::string& path) {
     it = line.begin() + 14; // ignore the first 14 characters
     end = line.end();
     std::tie(val, it) = Aux::Parsing::strTo<double>(it, end);
-    uint64_t nrows = (uint64_t) val;
+    uint64_t nrows = (uint64_t)val;
     DEBUG("line: ", line, "; ncols: ", nrows);
 
     // ** ignore remaining header info
@@ -51,22 +49,21 @@ RasterReader::read(const std::string& path) {
         std::getline(file, line);
     }
 
-
     // data for main loop
-    double xdelta = 1.0;// / (double) ncols; // width of each column
-    double ydelta = 1.0;// / (double) nrows; // height of each row
-    double xlb = 0.0;                     // lower bound in x-direction
-    double ylb = 1.0 - ydelta;            // lower bound in y-direction
-    double xub = xdelta;                  // upper bound in x-direction
-    double yub = 1.0;                     // upper bound in y-direction
+    double xdelta = 1.0;       // / (double) ncols; // width of each column
+    double ydelta = 1.0;       // / (double) nrows; // height of each row
+    double xlb = 0.0;          // lower bound in x-direction
+    double ylb = 1.0 - ydelta; // lower bound in y-direction
+    double xub = xdelta;       // upper bound in x-direction
+    double yub = 1.0;          // upper bound in y-direction
 #ifndef NDEBUG
-    double validate = 0.0;                // to validate the sum of the values
+    double validate = 0.0; // to validate the sum of the values
 #endif
 
     DEBUG("xdelta: ", xdelta, ", ydelta: ", ydelta);
 
-    std::vector<double> xcoords;          // stores the x-coordinates of generated points
-    std::vector<double> ycoords;          // stores the y-coordinates of generated points
+    std::vector<double> xcoords; // stores the x-coordinates of generated points
+    std::vector<double> ycoords; // stores the y-coordinates of generated points
 
     for (uint64_t row = 0; row < nrows; ++row) {
         std::getline(file, line);
@@ -82,7 +79,7 @@ RasterReader::read(const std::string& path) {
 
             // divide by "normalizer" and round down
             val *= normalizationFactor;
-            uint64_t numPointsInCell = (uint64_t) std::round(val);
+            uint64_t numPointsInCell = (uint64_t)std::round(val);
 
             for (uint64_t i = 0; i < numPointsInCell; ++i) {
                 // insert random coordinate into coordinate arrays
@@ -102,7 +99,8 @@ RasterReader::read(const std::string& path) {
         ylb -= ydelta;
     }
 #ifndef NDEBUG
-    DEBUG("Created ", xcoords.size(), " 2D points, validation: ", validate, " vs ", xcoords.size() / normalizationFactor);
+    DEBUG("Created ", xcoords.size(), " 2D points, validation: ", validate, " vs ",
+          xcoords.size() / normalizationFactor);
 #endif
     return std::make_pair(xcoords, ycoords);
 }
