@@ -1,4 +1,3 @@
-// no-networkit-format
 /*
  * SNAPGraphReader.cpp
  *
@@ -13,40 +12,41 @@
 
 namespace NetworKit {
 
-SNAPGraphReader::SNAPGraphReader(bool directed, const bool& remapNodes, const count& nodeCount) :
-directed(directed), nodeCount(nodeCount), remapNodes(remapNodes){}
+SNAPGraphReader::SNAPGraphReader(bool directed, const bool &remapNodes, const count &nodeCount)
+    : directed(directed), nodeCount(nodeCount), remapNodes(remapNodes) {}
 
 Graph SNAPGraphReader::read(const std::string &path) {
-    Graph graph(0,false,directed);
+    Graph graph(0, false, directed);
 
-    //In the actual state this parameter has very little influence on the reader performance.
-    //There can be a significant boost if it is possible to reserve space in the graph initialization
-    if(nodeCount != 0 && remapNodes)
+    // In the actual state this parameter has very little influence on the reader performance.
+    // There can be a significant boost if it is possible to reserve space in the graph
+    // initialization
+    if (nodeCount != 0 && remapNodes)
         nodeIdMap.reserve(nodeCount);
 
     // Maps SNAP node IDs to consecutive NetworKit node IDs.
-    auto mapNode = [&] (node in) -> node {
-        if (remapNodes){
+    auto mapNode = [&](node in) -> node {
+        if (remapNodes) {
             auto it = nodeIdMap.find(in);
-            if(it != nodeIdMap.end())
+            if (it != nodeIdMap.end())
                 return it->second;
             auto result = nodeIdMap.insert({in, graph.addNode()});
-            if(!result.second)
+            if (!result.second)
                 throw std::runtime_error("Error in mapping nodes");
             return result.first->second;
         }
-        for(count i = graph.upperNodeIdBound(); i < in + 1; i++)
+        for (count i = graph.upperNodeIdBound(); i < in + 1; i++)
             graph.addNode();
         return in;
     };
 
     // This function modifies the graph on input.
-    auto handleEdge = [&] (node source, node target) {
-        if(!graph.hasEdge(source, target)){
+    auto handleEdge = [&](node source, node target) {
+        if (!graph.hasEdge(source, target)) {
             graph.addEdge(source, target);
-        }else{
-            DEBUG("["+std::to_string(source)+"->"+std::to_string(target)+
-                "] Multiple edges detected");
+        } else {
+            DEBUG("[" + std::to_string(source) + "->" + std::to_string(target)
+                  + "] Multiple edges detected");
         }
     };
 
@@ -56,40 +56,40 @@ Graph SNAPGraphReader::read(const std::string &path) {
 
     // The following functions are helpers for parsing.
     auto skipWhitespace = [&] {
-        while(it != end && (*it == ' ' || *it == '\t'))
+        while (it != end && (*it == ' ' || *it == '\t'))
             ++it;
     };
 
-    auto scanId = [&] () -> node {
+    auto scanId = [&]() -> node {
         char *past;
         auto value = strtol(it, &past, 10);
-        if(past <= it)
+        if (past <= it)
             throw std::runtime_error("Error in parsing file - looking for nodeId failed");
         it = past;
         return value;
     };
 
     // This loop does the actual parsing.
-    while(it != end) {
-        if(it >= end)
+    while (it != end) {
+        if (it >= end)
             throw std::runtime_error("Unexpected end of file");
 
         skipWhitespace();
 
-        if(it == end)
+        if (it == end)
             throw std::runtime_error("Unexpected end of file");
 
-        if(*it == '\n') {
+        if (*it == '\n') {
             // We ignore empty lines.
-        }else if(*it == '#') {
+        } else if (*it == '#') {
             // Skip non-linebreak characters.
-            while(it != end && *it != '\n')
+            while (it != end && *it != '\n')
                 ++it;
-        }else{
+        } else {
             auto sourceId = scanId();
-            if(it == end)
+            if (it == end)
                 throw std::runtime_error("Unexpected end of file");
-            if(!(*it == ' ' || *it == '\t'))
+            if (!(*it == ' ' || *it == '\t'))
                 throw std::runtime_error("Error in parsing file - pointer is whitespace");
 
             skipWhitespace();
@@ -100,9 +100,9 @@ Graph SNAPGraphReader::read(const std::string &path) {
             handleEdge(mapNode(sourceId), mapNode(targetId));
         }
 
-        if(it == end)
+        if (it == end)
             throw std::runtime_error("Unexpected end of file");
-        if(!(*it == '\n' || *it == '\r'))
+        if (!(*it == '\n' || *it == '\r'))
             throw std::runtime_error("Line does not end with line break");
         ++it;
     }
