@@ -1,4 +1,3 @@
-// no-networkit-format
 /*
  * SNAPGraphWriter.cpp
  *
@@ -20,9 +19,7 @@ void SNAPGraphWriter::write(const Graph &G, const std::string &path) {
     // write "problem line" - n, m, directed/undirected, weighted/weight type
     file << "p " << G.numberOfNodes() << " " << G.numberOfEdges() << " u u 0\n"; // FIXME: makeshift
 
-    G.forEdges([&](node u, node v){
-        file << u << " " << v << '\n';
-    });
+    G.forEdges([&](node u, node v) { file << u << " " << v << '\n'; });
 
     file.close();
 }
