@@ -1,4 +1,3 @@
-// no-networkit-format
 /*
  * ThrillGraphBinaryWriter.cpp
  *
@@ -13,7 +12,8 @@ namespace NetworKit {
 
 void ThrillGraphBinaryWriter::write(const Graph &G, const std::string &path) {
     if (G.upperNodeIdBound() > std::numeric_limits<uint32_t>::max()) {
-        throw std::runtime_error("Thrill binary graphs only support graphs with up to 2^32-1 nodes.");
+        throw std::runtime_error(
+            "Thrill binary graphs only support graphs with up to 2^32-1 nodes.");
     }
 
     std::ofstream out_stream(path, std::ios::trunc | std::ios::binary);
@@ -34,11 +34,11 @@ void ThrillGraphBinaryWriter::write(const Graph &G, const std::string &path) {
         size_t deg = neighbors.size();
 
         // Write variable length int for the degree
-        if(!deg) {
+        if (!deg) {
             out_stream << uint8_t(0);
         }
 
-        while(deg) {
+        while (deg) {
             size_t u = deg & 0x7F;
             deg >>= 7;
             out_stream << uint8_t(u | (deg ? 0x80 : 0));
