@@ -1,4 +1,3 @@
-// no-networkit-format
 /*
  * Matching.cpp
  *
@@ -15,7 +14,7 @@ bool Matching::isMatched(node u) const {
     return (this->data.at(u) != none);
 }
 
-bool Matching::isProper(const Graph& G) const {
+bool Matching::isProper(const Graph &G) const {
     /**
      * The content of this data structure represents a matching iff
      * 	(for all v in V: M[v] = v or M[M[v]] = v) and
@@ -25,7 +24,7 @@ bool Matching::isProper(const Graph& G) const {
     // check if entries are symmetric
     for (node v : G.nodeRange()) {
         if (data.at(v) != none && data[data.at(v)] != v) {
-            DEBUG("node " , v , " is not symmetrically matched");
+            DEBUG("node ", v, " is not symmetrically matched");
             return false;
         }
     }
@@ -34,7 +33,7 @@ bool Matching::isProper(const Graph& G) const {
     for (node v : G.nodeRange()) {
         node w = data.at(v);
         if ((v != w) && (w != none) && !G.hasEdge(v, w)) {
-            DEBUG("matched pair (" , v , "," , w , ") is not an edge");
+            DEBUG("matched pair (", v, ",", w, ") is not an edge");
             return false;
         }
     }
@@ -56,7 +55,7 @@ bool Matching::areMatched(node u, node v) const {
     return (data.at(u) == v); // TODO: why not also data[v] == u ???
 }
 
-count Matching::size(const Graph& G) const {
+count Matching::size(const Graph &G) const {
     count size = 0;
     G.forNodes([&](node v) {
         if (isMatched(v)) {
@@ -70,10 +69,10 @@ index Matching::mate(node v) const {
     return data.at(v);
 }
 
-edgeweight Matching::weight(const Graph& G) const {
+edgeweight Matching::weight(const Graph &G) const {
     edgeweight weight = 0;
 
-    G.forNodes([&](node v){
+    G.forNodes([&](node v) {
         if (isMatched(v) && v < mate(v)) {
             weight += G.weight(v, mate(v));
         }
@@ -82,15 +81,15 @@ edgeweight Matching::weight(const Graph& G) const {
     return weight;
 }
 
-Partition Matching::toPartition(const Graph& G) const {
+Partition Matching::toPartition(const Graph &G) const {
     Partition partition(G.upperNodeIdBound());
     std::vector<bool> visited(G.upperNodeIdBound(), false);
-    G.forNodes([&](node u){
+    G.forNodes([&](node u) {
         if (!visited[u]) {
             if (mate(u) == none) {
-                partition.addToSubset(u,u);
+                partition.addToSubset(u, u);
             } else {
-                partition.addToSubset(u,u);
+                partition.addToSubset(u, u);
                 partition.addToSubset(u, mate(u));
                 visited[u] = true;
                 visited[mate(u)] = true;
@@ -101,8 +100,8 @@ Partition Matching::toPartition(const Graph& G) const {
 }
 
 std::vector<node> Matching::getVector() const {
-    return this->data; //FIXME is this appropriate? - why not?
+    return this->data; // FIXME is this appropriate? - why not?
 }
 
-}
- /* namespace NetworKit */
+} // namespace NetworKit
+  /* namespace NetworKit */
