@@ -1,4 +1,3 @@
-// no-networkit-format
 /*
  * MatcherGTest.cpp
  *
@@ -9,19 +8,19 @@
 #include <gtest/gtest.h>
 
 #include <networkit/auxiliary/Random.hpp>
-#include <networkit/matching/Matcher.hpp>
-#include <networkit/matching/Matching.hpp>
-#include <networkit/matching/PathGrowingMatcher.hpp>
-#include <networkit/matching/LocalMaxMatcher.hpp>
-#include <networkit/matching/SuitorMatcher.hpp>
 #include <networkit/graph/Graph.hpp>
 #include <networkit/graph/GraphTools.hpp>
 #include <networkit/io/DibapGraphReader.hpp>
 #include <networkit/io/METISGraphReader.hpp>
+#include <networkit/matching/LocalMaxMatcher.hpp>
+#include <networkit/matching/Matcher.hpp>
+#include <networkit/matching/Matching.hpp>
+#include <networkit/matching/PathGrowingMatcher.hpp>
+#include <networkit/matching/SuitorMatcher.hpp>
 
 namespace NetworKit {
 
-class MatcherGTest: public testing::Test {};
+class MatcherGTest : public testing::Test {};
 
 TEST_F(MatcherGTest, testLocalMaxMatching) {
     {
@@ -31,9 +30,7 @@ TEST_F(MatcherGTest, testLocalMaxMatching) {
 
     count n = 50;
     Graph G(n);
-    G.forNodePairs([&](node u, node v){
-        G.addEdge(u,v);
-    });
+    G.forNodePairs([&](node u, node v) { G.addEdge(u, v); });
 
     LocalMaxMatcher localMaxMatcher(G);
 
@@ -55,22 +52,20 @@ TEST_F(MatcherGTest, testLocalMaxMatching) {
     M = lmm.getMatching();
     isProper = M.isProper(airfoil1);
     EXPECT_TRUE(isProper);
-    DEBUG("LocalMax on airfoil1 produces matching of size: " , M.size(G));
+    DEBUG("LocalMax on airfoil1 produces matching of size: ", M.size(G));
 #endif
 }
 
 TEST_F(MatcherGTest, testLocalMaxMatchingDirectedWarning) {
     Graph G(2, false, true);
-    G.addEdge(0,1);
+    G.addEdge(0, 1);
     EXPECT_THROW(LocalMaxMatcher localMaxMatcher(G), std::runtime_error);
 }
 
 TEST_F(MatcherGTest, testPgaMatchingOnWeightedGraph) {
     count n = 50;
     Graph G(n);
-    G.forNodePairs([&](node u, node v){
-        G.addEdge(u,v, Aux::Random::real());
-    });
+    G.forNodePairs([&](node u, node v) { G.addEdge(u, v, Aux::Random::real()); });
     PathGrowingMatcher pgaMatcher(G);
     EXPECT_NO_THROW(pgaMatcher.run());
 }
@@ -78,22 +73,15 @@ TEST_F(MatcherGTest, testPgaMatchingOnWeightedGraph) {
 TEST_F(MatcherGTest, testPgaMatchingWithSelfLoops) {
     count n = 50;
     Graph G(n);
-    G.forNodePairs([&](node u, node v){
-        G.addEdge(u,v, Aux::Random::real());
-    });
-    G.forNodes([&](node u){
-        G.addEdge(u,u);
-    });
-    EXPECT_THROW(PathGrowingMatcher pgaMatcher(G),std::invalid_argument);
+    G.forNodePairs([&](node u, node v) { G.addEdge(u, v, Aux::Random::real()); });
+    G.forNodes([&](node u) { G.addEdge(u, u); });
+    EXPECT_THROW(PathGrowingMatcher pgaMatcher(G), std::invalid_argument);
 }
 
-
 TEST_F(MatcherGTest, testPgaMatching) {
     count n = 50;
     Graph G(n);
-    G.forNodePairs([&](node u, node v){
-        G.addEdge(u,v);
-    });
+    G.forNodePairs([&](node u, node v) { G.addEdge(u, v); });
     PathGrowingMatcher pgaMatcher(G);
 
     DEBUG("Start PGA matching on 50-clique");
@@ -107,7 +95,6 @@ TEST_F(MatcherGTest, testPgaMatching) {
     EXPECT_EQ(M.size(G), numExpEdges);
     DEBUG("Finished PGA matching on 50-clique");
 
-
 #if !defined _WIN32 && !defined _WIN64 && !defined WIN32 && !defined WIN64
     DibapGraphReader reader;
     Graph airfoil1 = reader.read("input/airfoil1.gi");
@@ -116,7 +103,7 @@ TEST_F(MatcherGTest, testPgaMatching) {
     M = pga2.getMatching();
     isProper = M.isProper(airfoil1);
     EXPECT_TRUE(isProper);
-    DEBUG("PGA on airfoil1 produces matching of size: " , M.size(G));
+    DEBUG("PGA on airfoil1 produces matching of size: ", M.size(G));
 #endif
 }
 
@@ -133,12 +120,12 @@ TEST_F(MatcherGTest, debugValidMatching) {
 }
 
 TEST_F(MatcherGTest, testSuitorMatcher) {
-    {   // Directed graphs are not supported
+    { // Directed graphs are not supported
         Graph G(10, true, true);
         EXPECT_THROW(SuitorMatcher{G}, std::runtime_error);
     }
 
-    {   // Graphs with self loops are not supported
+    { // Graphs with self loops are not supported
         Graph G(10);
         G.addEdge(0, 0);
         G.addEdge(0, 0);
@@ -192,9 +179,8 @@ TEST_F(MatcherGTest, testSuitorMatcher) {
 
         // Test weighted
         G = GraphTools::toWeighted(G);
-        G.forEdges([&G, maxWeight](node u, node v) {
-            G.setWeight(u, v, Aux::Random::real(maxWeight));
-        });
+        G.forEdges(
+            [&G, maxWeight](node u, node v) { G.setWeight(u, v, Aux::Random::real(maxWeight)); });
         doTest(G);
     }
 }
