@@ -1,4 +1,3 @@
-// no-networkit-format
 /*
  * SimmelianScore.cpp
  *
@@ -6,31 +5,32 @@
  *      Author: Gerd Lindner
  */
 
-#include <networkit/sparsification/SimmelianScore.hpp>
 #include <limits>
+#include <networkit/sparsification/SimmelianScore.hpp>
 
 namespace NetworKit {
 
-SimmelianScore::SimmelianScore(const Graph& G, const std::vector<count>& triangles) : EdgeScore<double>(G), triangles(&triangles) {
-}
+SimmelianScore::SimmelianScore(const Graph &G, const std::vector<count> &triangles)
+    : EdgeScore<double>(G), triangles(&triangles) {}
 
-std::vector<RankedNeighbors> SimmelianScore::getRankedNeighborhood(const Graph& g, const std::vector<count>& triangles) {
+std::vector<RankedNeighbors>
+SimmelianScore::getRankedNeighborhood(const Graph &g, const std::vector<count> &triangles) {
     std::vector<RankedNeighbors> neighbors;
     neighbors.resize(g.upperNodeIdBound());
 
     g.forNodes([&](node u) {
-        //Sort ego's alters from strongly to weakly tied.
+        // Sort ego's alters from strongly to weakly tied.
         g.forNeighborsOf(u, [&](node, node v, edgeid eid) {
             count triangleCount = std::round(triangles[eid]);
             neighbors[u].push_back(RankedEdge(u, v, triangleCount));
         });
         std::sort(neighbors[u].begin(), neighbors[u].end());
 
-        //Calculate the ranks.
-        count currentRank = 0;	//Rank 0 is considered the best.
+        // Calculate the ranks.
+        count currentRank = 0; // Rank 0 is considered the best.
         count currentSimmelianness = std::numeric_limits<count>::max();
         count equals = 0;
-        for (auto& edge : neighbors[u]) {
+        for (auto &edge : neighbors[u]) {
             if (edge.simmelianness != currentSimmelianness) {
                 currentRank += equals;
                 currentSimmelianness = edge.simmelianness;
@@ -43,14 +43,12 @@ std::vector<RankedNeighbors> SimmelianScore::getRankedNeighborhood(const Graph&
     });
 
     return neighbors;
-
 }
 
-Redundancy SimmelianScore::getOverlap(	const node& ego,
-                                                const node& alter,
-                                                const std::vector<RankedNeighbors>& neighbors,
-                                                const count& maxRank) {
-    //Initialization of output values
+Redundancy SimmelianScore::getOverlap(const node &ego, const node &alter,
+                                      const std::vector<RankedNeighbors> &neighbors,
+                                      const count &maxRank) {
+    // Initialization of output values
     Redundancy result = Redundancy(0, 0.0);
 
     std::vector<RankedEdge>::const_iterator egoIt = neighbors[ego].begin();
@@ -60,12 +58,16 @@ Redundancy SimmelianScore::getOverlap(	const node& ego,
     std::unordered_set<node> alterNeighborsUnmatched;
 
     for (count rank = 0; rank <= maxRank; rank++) {
-        matchNeighbors(ego, alter, true, egoIt, neighbors[ego], egoNeighborsUnmatched, alterNeighborsUnmatched, rank, result.overlap);
-        matchNeighbors(alter, ego, false, alterIt, neighbors[alter], alterNeighborsUnmatched, egoNeighborsUnmatched, rank, result.overlap);
+        matchNeighbors(ego, alter, true, egoIt, neighbors[ego], egoNeighborsUnmatched,
+                       alterNeighborsUnmatched, rank, result.overlap);
+        matchNeighbors(alter, ego, false, alterIt, neighbors[alter], alterNeighborsUnmatched,
+                       egoNeighborsUnmatched, rank, result.overlap);
 
         double currentJaccard = 0.0;
         if (result.overlap + egoNeighborsUnmatched.size() + alterNeighborsUnmatched.size() > 0)
-            currentJaccard = double(result.overlap) / double(result.overlap + egoNeighborsUnmatched.size() + alterNeighborsUnmatched.size());
+            currentJaccard = double(result.overlap)
+                             / double(result.overlap + egoNeighborsUnmatched.size()
+                                      + alterNeighborsUnmatched.size());
 
         result.jaccard = std::max(currentJaccard, result.jaccard);
     }
