@@ -1,4 +1,3 @@
-// no-networkit-format
 /*
  * MaxentStressGTest.cpp
  *
@@ -6,36 +5,36 @@
  *      Author: Michael
  */
 
-#include <gtest/gtest.h>
-#include <vector>
 #include <string>
+#include <vector>
+#include <gtest/gtest.h>
 
 #include <networkit/graph/Graph.hpp>
 #include <networkit/viz/Point.hpp>
 
+#include <networkit/components/ConnectedComponents.hpp>
+#include <networkit/graph/Graph.hpp>
 #include <networkit/io/METISGraphReader.hpp>
 #include <networkit/io/METISGraphWriter.hpp>
-#include <networkit/graph/Graph.hpp>
-#include <networkit/components/ConnectedComponents.hpp>
 #include <networkit/viz/MaxentStress.hpp>
 
-#include <networkit/numerics/LAMG/Lamg.hpp>
 #include <networkit/numerics/ConjugateGradient.hpp>
-#include <networkit/numerics/Preconditioner/IdentityPreconditioner.hpp>
+#include <networkit/numerics/LAMG/Lamg.hpp>
 #include <networkit/numerics/Preconditioner/DiagonalPreconditioner.hpp>
+#include <networkit/numerics/Preconditioner/IdentityPreconditioner.hpp>
 
 #include <networkit/community/PLM.hpp>
 
+#include <networkit/sparsification/GlobalThresholdFilter.hpp>
 #include <networkit/sparsification/LocalDegreeScore.hpp>
 #include <networkit/sparsification/RandomEdgeScore.hpp>
-#include <networkit/sparsification/GlobalThresholdFilter.hpp>
 
-#include <networkit/auxiliary/Timer.hpp>
 #include <networkit/auxiliary/Random.hpp>
+#include <networkit/auxiliary/Timer.hpp>
 
 #include <iostream>
-#include <unordered_map>
 #include <random>
+#include <unordered_map>
 
 #include <networkit/viz/PivotMDS.hpp>
 
@@ -50,7 +49,7 @@ TEST_F(MaxentStressGTest, benchMaxentStressCoordinatesLAMG) {
     std::vector<std::string> graphFiles = {"input/airfoil1.graph"};
     METISGraphReader reader;
 
-    for (const std::string& graphFile : graphFiles) {
+    for (const std::string &graphFile : graphFiles) {
         Graph graph = reader.read(graphFile);
 
         double runtime = 0;
@@ -62,7 +61,8 @@ TEST_F(MaxentStressGTest, benchMaxentStressCoordinatesLAMG) {
         t.start();
         PivotMDS pivotMds(graph, 2, 30);
         pivotMds.run();
-        MaxentStress maxentStressAlgo(graph, 2, pivotMds.getCoordinates(), 1, 0.001, MaxentStress::LinearSolverType::LAMG);
+        MaxentStress maxentStressAlgo(graph, 2, pivotMds.getCoordinates(), 1, 0.001,
+                                      MaxentStress::LinearSolverType::LAMG);
         maxentStressAlgo.run();
         t.stop();
 
@@ -73,7 +73,6 @@ TEST_F(MaxentStressGTest, benchMaxentStressCoordinatesLAMG) {
             maxentStress = maxentStressAlgo.maxentMeasure();
         }
 
-
         runtime /= 1000;
 
         INFO(graphFile, "\t", maxentStress, "\t", fullStress, "\t", runtime);
@@ -84,7 +83,7 @@ TEST_F(MaxentStressGTest, benchMaxentStressConjGradIdPrecAlgebraicDistance) {
     std::vector<std::string> graphFiles = {"input/airfoil1.graph"};
     METISGraphReader reader;
 
-    for (const std::string& graphFile : graphFiles) {
+    for (const std::string &graphFile : graphFiles) {
         Graph graph = reader.read(graphFile);
 
         double runtime = 0;
@@ -94,7 +93,10 @@ TEST_F(MaxentStressGTest, benchMaxentStressConjGradIdPrecAlgebraicDistance) {
 
         Aux::Timer t;
         t.start();
-        MaxentStress maxentStressAlgo(graph, 2, 1, 0.001, MaxentStress::LinearSolverType::CONJUGATE_GRADIENT_IDENTITY_PRECONDITIONER, true, MaxentStress::GraphDistance::ALGEBRAIC_DISTANCE);
+        MaxentStress maxentStressAlgo(
+            graph, 2, 1, 0.001,
+            MaxentStress::LinearSolverType::CONJUGATE_GRADIENT_IDENTITY_PRECONDITIONER, true,
+            MaxentStress::GraphDistance::ALGEBRAIC_DISTANCE);
         maxentStressAlgo.run();
         t.stop();
 
@@ -105,10 +107,9 @@ TEST_F(MaxentStressGTest, benchMaxentStressConjGradIdPrecAlgebraicDistance) {
             maxentStress = maxentStressAlgo.maxentMeasure();
         }
 
-
         runtime /= 1000;
 
-    INFO(graphFile, "\t", maxentStress, "\t", fullStress, "\t", runtime);
+        INFO(graphFile, "\t", maxentStress, "\t", fullStress, "\t", runtime);
     }
 }
 
@@ -116,7 +117,7 @@ TEST_F(MaxentStressGTest, benchMaxentStressConjGradDiagPrecond) {
     std::vector<std::string> graphFiles = {"input/airfoil1.graph"};
     METISGraphReader reader;
 
-    for (const std::string& graphFile : graphFiles) {
+    for (const std::string &graphFile : graphFiles) {
         Graph graph = reader.read(graphFile);
 
         double runtime = 0;
@@ -126,7 +127,9 @@ TEST_F(MaxentStressGTest, benchMaxentStressConjGradDiagPrecond) {
 
         Aux::Timer t;
         t.start();
-        MaxentStress maxentStressAlgo(graph, 2, 1, 0.001, MaxentStress::LinearSolverType::CONJUGATE_GRADIENT_DIAGONAL_PRECONDITIONER);
+        MaxentStress maxentStressAlgo(
+            graph, 2, 1, 0.001,
+            MaxentStress::LinearSolverType::CONJUGATE_GRADIENT_DIAGONAL_PRECONDITIONER);
         maxentStressAlgo.run();
         t.stop();
 
@@ -137,7 +140,6 @@ TEST_F(MaxentStressGTest, benchMaxentStressConjGradDiagPrecond) {
             maxentStress = maxentStressAlgo.maxentMeasure();
         }
 
-
         runtime /= 1000;
 
         INFO(graphFile, "\t", maxentStress, "\t", fullStress, "\t", runtime);
@@ -148,7 +150,7 @@ TEST_F(MaxentStressGTest, benchMaxentStressCoordConjGradIdPrecond) {
     std::vector<std::string> graphFiles = {"input/airfoil1.graph"};
     METISGraphReader reader;
 
-    for (const std::string& graphFile : graphFiles) {
+    for (const std::string &graphFile : graphFiles) {
         Graph graph = reader.read(graphFile);
 
         double runtime = 0;
@@ -160,7 +162,10 @@ TEST_F(MaxentStressGTest, benchMaxentStressCoordConjGradIdPrecond) {
         t.start();
         PivotMDS pivotMds(graph, 2, 30);
         pivotMds.run();
-        MaxentStress maxentStressAlgo(graph, 2, pivotMds.getCoordinates(), 1, 0.001, MaxentStress::LinearSolverType::CONJUGATE_GRADIENT_IDENTITY_PRECONDITIONER, false, MaxentStress::GraphDistance::ALGEBRAIC_DISTANCE);
+        MaxentStress maxentStressAlgo(
+            graph, 2, pivotMds.getCoordinates(), 1, 0.001,
+            MaxentStress::LinearSolverType::CONJUGATE_GRADIENT_IDENTITY_PRECONDITIONER, false,
+            MaxentStress::GraphDistance::ALGEBRAIC_DISTANCE);
         maxentStressAlgo.run();
         t.stop();
 
@@ -171,7 +176,6 @@ TEST_F(MaxentStressGTest, benchMaxentStressCoordConjGradIdPrecond) {
             maxentStress = maxentStressAlgo.maxentMeasure();
         }
 
-
         runtime /= 1000;
 
         INFO(graphFile, "\t", maxentStress, "\t", fullStress, "\t", runtime);
